@@ -24,6 +24,7 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include "ksdebug.h"
+#include <kglobalsettings.h>
 #include <kimageio.h>
 
 #include "dialoglauncher-gui.h"
@@ -330,7 +331,7 @@ int main(int argc, char *argv[]) {
 
   KAboutData aboutData("kst", I18N_NOOP("Kst"),
                        KSTVERSION, description, KAboutData::License_GPL,
-                       I18N_NOOP("(c) 2000-2006 Barth Netterfield"),
+                       I18N_NOOP("(c) 2000-2007 Barth Netterfield"),
                        0,
                        "http://kst.kde.org/");
   aboutData.addAuthor("Barth Netterfield",
@@ -349,6 +350,10 @@ int main(int argc, char *argv[]) {
                       I18N_NOOP("University of British Columbia"),
                       "",
                       "");
+  aboutData.addAuthor("Duncan Hanson",
+                      I18N_NOOP("University of British Columbia"),
+                      "",
+                      "");
   aboutData.addAuthor("Nicolas Brisset",
                       "",
                       "",
@@ -414,6 +419,8 @@ int main(int argc, char *argv[]) {
 
     if (!print_and_exit) {
       app.setMainWidget(kst);
+      QRect rect = KGlobalSettings::desktopGeometry(kst);
+      kst->resize(5 * rect.width() / 6, 5 * rect.height() / 6);
       kst->show();
     }
 
@@ -513,7 +520,9 @@ int main(int argc, char *argv[]) {
         } else {
           fullPath = args->arg(i_file);
         }
+
         KstDataSourcePtr file = KstDataSource::loadSource(fullPath);
+
         if (file) {
           if (!file->isValid() || file->isEmpty()) {
             kstdError() << i18n("No data in file %1.  Trying to continue...").arg(args->arg(i_file)) << endl;
@@ -541,7 +550,7 @@ int main(int argc, char *argv[]) {
                 if (yvector) {
                   // make the curves
                   color = KstColorSequence::next(vcurves,plot->backgroundColor());
-                  curve = new KstVCurve(KST::suggestCurveName(yvector->tag(), false), // FIXME: this was yvector->field(), is this right?
+                  curve = new KstVCurve(KST::suggestCurveName(yvector->tag(), false),
                                       KstVectorPtr(xvector), KstVectorPtr(yvector),
                                       0L, 0L, 0L, 0L, color);
                   if (in.has_points) {
@@ -666,7 +675,7 @@ int main(int argc, char *argv[]) {
 
                 KstHistogram::AutoBin(KstVectorPtr(yvector), &N, &max, &min);
 
-                hs = new KstHistogram(KST::suggestHistogramName(yvector->tag()), // FIXME: this was yvector->field(), is this right?
+                hs = new KstHistogram(KST::suggestHistogramName(yvector->tag()),
                     KstVectorPtr(yvector), min, max, N, KST_HS_NUMBER);
                 KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(hs->tag(), true),
                     hs->vX(), hs->vY(),
@@ -797,12 +806,14 @@ int main(int argc, char *argv[]) {
       kst->immediatePrintToPng(pngfile);
     }
 
+    kst->document()->setModified(false);
+
     if (print_and_exit) {
       delete kst;
       return 0;
     } else {
       kst->updateDialogs();
-      
+
       if (showQuickStart) {
         kst->showQuickStartDialog();
       }
