@@ -318,6 +318,24 @@ bool KstDataSource::supportsTime(const QString& filename, const QString& type) {
 }
 
 
+bool KstDataSource::supportsHierarchy(const QString& filename, const QString& type) {
+  if (filename.isEmpty() || filename == "stdin" || filename == "-") {
+    return false;
+  }
+
+  QString fn = obtainFile(filename);
+  if (fn.isEmpty()) {
+    return false;
+  }
+
+  QValueList<PluginSortContainer> bestPlugins = bestPluginsForSource(fn, type);
+  if (bestPlugins.isEmpty()) {
+    return false;
+  }
+  return (*bestPlugins.begin()).plugin->supportsHierarchy();
+}
+
+
 QStringList KstDataSource::fieldListForSource(const QString& filename, const QString& type, QString *outType, bool *complete) {
   if (filename == "stdin" || filename == "-") {
     return QStringList();
@@ -330,13 +348,13 @@ QStringList KstDataSource::fieldListForSource(const QString& filename, const QSt
 
   QValueList<PluginSortContainer> bestPlugins = bestPluginsForSource(fn, type);
   QStringList rc;
-  for (QValueList<PluginSortContainer>::Iterator i = bestPlugins.begin(); i != bestPlugins.end(); ++i) {
+  for (QValueList<PluginSortContainer>::Iterator it = bestPlugins.begin(); it != bestPlugins.end(); ++it) {
     QString typeSuggestion;
-    rc = (*i).plugin->fieldList(kConfigObject, fn, QString::null, &typeSuggestion, complete);
+    rc = (*it).plugin->fieldList(kConfigObject, fn, QString::null, &typeSuggestion, complete);
     if (!rc.isEmpty()) {
       if (outType) {
         if (typeSuggestion.isEmpty()) {
-          *outType = (*i).plugin->provides()[0];
+          *outType = (*it).plugin->provides()[0];
         } else {
           *outType = typeSuggestion;
         }
@@ -345,6 +363,21 @@ QStringList KstDataSource::fieldListForSource(const QString& filename, const QSt
     }
   }
 
+  if (!rc.isEmpty()) {
+    //
+    // check for duplicate field names and warn the user if necessary...
+    //
+    QMap<QString, QString> map;
+
+    for (QStringList::const_iterator it = rc.begin(); it != rc.end(); ++it) {
+      map.insert(*it, *it);
+    }
+
+    if (map.size() != rc.size()) {
+      KstDebug::self()->log( i18n("The datasource '%1' has at least one duplicate field name. As a result one or more fields will not be accessible.").arg(filename), KstDebug::Error);
+    }
+  }
+
   return rc;
 }
 
@@ -675,40 +708,50 @@ bool KstDataSource::supportsTimeConversions() const {
 
 int KstDataSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
   Q_UNUSED(time)
+
   if (ok) {
     *ok = false;
   }
+
   return 0;
 }
 
 
-
 int KstDataSource::sampleForTime(double ms, bool *ok) {
   Q_UNUSED(ms)
+
   if (ok) {
     *ok = false;
   }
+
   return 0;
 }
 
 
-
 KST::ExtDateTime KstDataSource::timeForSample(int sample, bool *ok) {
   Q_UNUSED(sample)
+
   if (ok) {
     *ok = false;
   }
+
   return KST::ExtDateTime::currentDateTime();
 }
 
 
-
 double KstDataSource::relativeTimeForSample(int sample, bool *ok) {
   Q_UNUSED(sample)
+
   if (ok) {
     *ok = false;
   }
-  return 0;
+
+  return 0.0;
+}
+
+
+bool KstDataSource::supportsHierarchy() const {
+  return false;
 }
 
 
