@@ -74,12 +74,18 @@ class KST_EXPORT KstVector : public KstPrimitive {
     /** Return V[i] uninterpolated */
     double value(int i);
 
-    /** Return Minimum value in Vector */
+    /** Return minimum value in Vector */
     inline double min() const { return _min; }
 
-    /** Return max value in Vector */
+    /** Return maximum value in Vector */
     inline double max() const { return _max; }
 
+    /** Return index of minimum value in Vector */
+    inline double minIndex() const { return _minIndex; }
+
+    /** Return index of maximum value in Vector */
+    inline double maxIndex() const { return _maxIndex; }
+
     /** Return SpikeInsensitive max value in vector **/
     inline double ns_max() const { return _ns_max; }
 
@@ -138,7 +144,7 @@ class KST_EXPORT KstVector : public KstPrimitive {
 
     /** access functions for _isScalarList */
     bool isScalarList() const { return _isScalarList; }
-    
+
     const QDict<KstScalar>& scalars() const;
 
     void setLabel(const QString& label_in);
@@ -151,6 +157,8 @@ class KST_EXPORT KstVector : public KstPrimitive {
     bool saveData() const;
     virtual void setSaveData(bool save);
 
+    int indexNearX(double x, int NS); //returns the index of the element w/ value closest to v.
+
   protected:
     /** current number of samples */
     int _size;
@@ -192,13 +200,14 @@ class KST_EXPORT KstVector : public KstPrimitive {
     bool _saveData : 1;
 
     double _min, _max, _mean, _minPos;
+    int _minIndex, _maxIndex;
 
     /** Scalar Maintenance methods */
-    void CreateScalars();
-    void RenameScalars();
+    void createScalars();
+    void renameScalars();
 
     QString _label;
-    
+
     friend class KstDataObject;
     virtual double* realloced(double *memptr, int newSize);
     KstObject::UpdateType internalUpdate(KstObject::UpdateType providerRC);
