@@ -25,6 +25,7 @@
 #include "kstplugindialog_i.h"
 #include "kstbasicdialog_i.h"
 #include "kstpsddialog_i.h"
+#include "kstvvdialog_i.h"
 #include "kstvectordialog_i.h"
 
 
@@ -90,6 +91,14 @@ void KstGuiDialogs::showPSDDialog(const QString& name, bool edit) {
   }
 }
 
+void KstGuiDialogs::showVectorViewDialog(const QString& name, bool edit) {
+  if (!edit) {
+    KstVvDialogI::globalInstance()->showNew(name);
+  } else {
+    KstVvDialogI::globalInstance()->showEdit(name);
+  }
+}
+
 
 void KstGuiDialogs::newVectorDialog(QWidget *parent, const char *createdSlot, const char *selectedSlot, const char *updateSlot) {
   KstVectorDialogI *ad = new KstVectorDialogI(parent, "vector dialog");
