@@ -55,7 +55,7 @@
 #include "kstcsddialog_i.h"
 #include "kstdatamanager_i.h"
 #include "kstdatanotifier.h"
-#include "datawizard.h"
+#include "kstdatawizard_i.h"
 #include "kstdebugdialog_i.h"
 #include "kstdebugnotifier.h"
 #include "kstdoc.h"
@@ -67,17 +67,20 @@
 #include "kstfilterdialog_i.h"
 #include "kstgraphfiledialog_i.h"
 #include "ksthsdialog_i.h"
+#include "kstvvdialog_i.h"
 #include "kstiface_impl.h"
 #include "kstimagedialog_i.h"
+#include "kstlegenddefaults.h"
 #include "kstlogwidget.h"
 #include "kstmatrixdialog_i.h"
 #include "kstmatrixdefaults.h"
 #include "kstmonochromedialog_i.h"
 #include "kstplugindialog_i.h"
+#include "kstbasicdialog_i.h"
 #include "kstprintoptionspage.h"
 #include "kstpsddialog_i.h"
 #include "kstquickstartdialog_i.h"
-#include "kstsettingsdlg.h"
+#include "kstsettingsdlg_i.h"
 #include "kstuinames.h"
 #include "kstvectordefaults.h"
 #include "kstvectordialog_i.h"
@@ -98,6 +101,8 @@
 #include "vectorsavedialog.h"
 #include "kstobjectdefaults.h"
 
+#define MODE_BUTTON_ID       5
+
 #define KST_STATUSBAR_DATA   1
 #define KST_STATUSBAR_STATUS 2
 
@@ -849,7 +854,7 @@ void KstApp::initActions() {
   _gfxPictureAction->plug(mouseModeMenu);
   _gfx2DPlotAction->plug(mouseModeMenu);
 
-  toolBar()->insertButton("thumbnail", 5, mouseModeMenu, true, i18n("Select the desired mode"));
+  toolBar()->insertButton("thumbnail", MODE_BUTTON_ID, mouseModeMenu, true, i18n("Select the desired mode"));
   toggleMouseMode();
 
   createGUI(0L);
@@ -964,7 +969,7 @@ void KstApp::delayedDocInit() {
 void KstApp::selectDataPlugin() {
   QStringList l;
 
-  //The new KstDataObject plugins...
+  // the new KstDataObject plugins...
   QStringList newPlugins;
   const KstPluginInfoList pluginInfo = KstDataObject::pluginInfoList();
   {
@@ -976,7 +981,7 @@ void KstApp::selectDataPlugin() {
 
   l += newPlugins;
 
-  //The old C style plugins...
+  // the old C style plugins...
   QStringList oldPlugins;
   const QMap<QString,QString> readable = PluginCollection::self()->readableNameList();
   {
@@ -988,20 +993,21 @@ void KstApp::selectDataPlugin() {
 
   l += oldPlugins;
 
+  // list the old and new stlye plugins together in ascending alphabetical order...
+  l.sort();
+
   bool ok = false;
   QStringList plugin = KInputDialog::getItemList(i18n("Data Plugins"), i18n("Create..."), l, 0, false, &ok, this);
 
-  if (!ok || plugin.isEmpty()) {
-    return;
-  }
+  if (ok && !plugin.isEmpty()) {
+    const QString p = plugin.join("");
 
-  const QString p = plugin.join("");
-
-  if (newPlugins.contains(p)) {
-    KstDataObjectPtr ptr = KstDataObject::plugin(p);
-    ptr->showDialog(true);
-  } else if (oldPlugins.contains(p)) {
-    KstPluginDialogI::globalInstance()->showNew(readable[p]);
+    if (newPlugins.contains(p)) {
+      KstDataObjectPtr ptr = KstDataObject::plugin(p);
+      ptr->showDialog(true);
+    } else if (oldPlugins.contains(p)) {
+      KstPluginDialogI::globalInstance()->showNew(readable[p]);
+    }
   }
 }
 
@@ -1100,6 +1106,7 @@ void KstApp::saveOptions() {
   config->setGroup("General Options");
   _recent->saveEntries(config, "Recent Files");
 
+  KST::legendDefaults.writeConfig(config);
   KST::vectorDefaults.writeConfig(config);
   KST::matrixDefaults.writeConfig(config);
   KST::objectDefaults.writeConfig(config);
@@ -1111,6 +1118,7 @@ void KstApp::readOptions() {
   config->setGroup("General Options");
   _recent->loadEntries(config, "Recent Files");
 
+  KST::legendDefaults.readConfig(config);
   KST::vectorDefaults.readConfig(config);
   KST::matrixDefaults.readConfig(config);
   KST::objectDefaults.readConfig(config);
@@ -1856,11 +1864,16 @@ void KstApp::toggleMouseMode() {
     mode = KstTopLevelView::DisplayMode;
   }
 
-  DataMode->setEnabled(!LayoutAction->isChecked());
-  _tiedZoomAction->setEnabled(!LayoutAction->isChecked());
+  if (XZoomAction->isChecked() ||
+      YZoomAction->isChecked() ||
+      XYZoomAction->isChecked()) {
+    DataMode->setEnabled(true);
+  } else {
+    DataMode->setEnabled(false);
+  }
 
   if (action) {
-    KToolBarButton* button = toolBar()->getButton(5);
+    KToolBarButton* button = toolBar()->getButton(MODE_BUTTON_ID);
 
     if (button) {
       button->setText(action->toolTip());
@@ -1943,6 +1956,7 @@ void KstApp::newPlot() {
     assert(w);
   }
   w->createPlot(KST::suggestPlotName(), false);
+  updateDialogsForPlot();
 }
 
 
@@ -2072,7 +2086,7 @@ void KstApp::updateDataDialogs(bool dm, bool vm) {
   if (vm) {
     viewManager->updateContents();
   }
-  
+
   updateMemoryStatus();
 }
 
@@ -2091,6 +2105,9 @@ void KstApp::updateDialogs(bool onlyVisible) {
     if (!onlyVisible || KstVectorDialogI::globalInstance()->isShown()) {
       KstVectorDialogI::globalInstance()->update();
     }
+    if (!onlyVisible || KstBasicDialogI::globalInstance()->isShown()) {
+      KstBasicDialogI::globalInstance()->updateForm();
+    }
     if (!onlyVisible || KstPluginDialogI::globalInstance()->isShown()) {
       KstPluginDialogI::globalInstance()->updateForm();
     }
@@ -2106,6 +2123,9 @@ void KstApp::updateDialogs(bool onlyVisible) {
     if (!onlyVisible || KstHsDialogI::globalInstance()->isShown()) {
       KstHsDialogI::globalInstance()->update();
     }
+    if (!onlyVisible || KstVvDialogI::globalInstance()->isShown()) {
+      KstVvDialogI::globalInstance()->update();
+    }
     if (!onlyVisible || KstPsdDialogI::globalInstance()->isShown()) {
       KstPsdDialogI::globalInstance()->update();
     }
@@ -2154,6 +2174,22 @@ void KstApp::updateDialogsForWindow() {
     KstCsdDialogI::globalInstance()->updateWindow();
     KstEqDialogI::globalInstance()->updateWindow();
     KstHsDialogI::globalInstance()->updateWindow();
+    KstVvDialogI::globalInstance()->updateWindow();
+    KstPsdDialogI::globalInstance()->updateWindow();
+    KstCurveDialogI::globalInstance()->updateWindow();
+    KstImageDialogI::globalInstance()->updateWindow();
+    updateDataManager(false);
+    updateViewManager(false);
+  }
+}
+
+
+void KstApp::updateDialogsForPlot() {
+  if (!_stopping) {
+    KstCsdDialogI::globalInstance()->updateWindow();
+    KstEqDialogI::globalInstance()->updateWindow();
+    KstHsDialogI::globalInstance()->updateWindow();
+    KstVvDialogI::globalInstance()->updateWindow();
     KstPsdDialogI::globalInstance()->updateWindow();
     KstCurveDialogI::globalInstance()->updateWindow();
     KstImageDialogI::globalInstance()->updateWindow();
@@ -2194,7 +2230,7 @@ void KstApp::showExtensionManager() {
 
 
 void KstApp::showDataWizard() {
-  DataWizard *dw = new DataWizard(this, "DataWizard");
+  KstDataWizard *dw = new KstDataWizard(this, "DataWizard");
   dw->exec();
   if (dw->result() == QDialog::Accepted) {
     delete dw; // leave this here - releases references
@@ -2208,7 +2244,7 @@ void KstApp::showDataWizard() {
 
 
 void KstApp::showDataWizardWithFile(const QString &input) {
-  DataWizard *dw = new DataWizard(this, "DataWizard");
+  KstDataWizard *dw = new KstDataWizard(this, "DataWizard");
   dw->setInput(input);
   dw->exec();
   if (dw->result() == QDialog::Accepted) {
@@ -2257,7 +2293,7 @@ void KstApp::reload() {
 
 
 void KstApp::slotPreferences() {
-  KstSettingsDlg *ksd = new KstSettingsDlg(this, "Kst Settings Dialog");
+  KstSettingsDlgI *ksd = new KstSettingsDlgI(this, "Kst Settings Dialog");
   connect(ksd, SIGNAL(settingsChanged()), this, SIGNAL(settingsChanged()));
   ksd->exec();
   delete ksd;
@@ -2605,4 +2641,4 @@ void KstApp::emitTimezoneChanged(const QString& tz, int utcOffset) {
 }
 
 #include "kst.moc"
-// vim: ts=2 sw=2 et
+
