@@ -20,6 +20,10 @@
 
 #include <time.h>
 
+#include <qvaluestack.h>
+
+#include <kmessagebox.h>
+
 #include "kstbackbuffer.h"
 #include "kstbasecurve.h"
 #include "kstcolorsequence.h"
@@ -28,8 +32,7 @@
 #include "kstviewwidget.h"
 #include "kstviewlegend.h"
 #include "kst_export.h"
-
-#include <qvaluestack.h>
+#include "kstscalar.h"
 
 namespace Equation {
   class Node;
@@ -89,29 +92,31 @@ public:
   Kst2DPlot(const QString& in_tag = "SomePlot",
           KstScaleModeType yscale = AUTOBORDER,
           KstScaleModeType xscale = AUTO,
-          double xmin = 0, double ymin = 0,
-          double xmax = 1, double ymax = 1);
+          double xmin = 0.0, double ymin = 0.0,
+          double xmax = 1.0, double ymax = 1.0);
   Kst2DPlot(const QDomElement& e);
   Kst2DPlot(const Kst2DPlot& plot, const QString& name);
   virtual ~Kst2DPlot();
 
-  QWidget *configWidget();
+  QWidget *configWidget(QWidget *parent);
 
   // handle custom widget, if any: is called by KstEditViewObjectDialogI
   bool fillConfigWidget(QWidget *w, bool isNew) const;
-  bool readConfigWidget(QWidget *w);
+  bool readConfigWidget(QWidget *w, bool editMultipleMode);
   void connectConfigWidget(QWidget *parent, QWidget *w) const;
-    
+  void populateEditMultiple(QWidget *w);
+  bool supportsDefaults();
+
   static Kst2DPlotList globalPlotList();
   static Kst2DPlotPtr findPlotByName(const QString& name);
   static bool checkRange(double& min_in, double& max_in);
   static bool checkLRange(double& min_in, double& max_in, bool isLog, double logBase);
-  static void genAxisTickLabel(QString& label, double z, bool isLog, double logBase);
+  static void genAxisTickLabel(QString& label, double z, bool isLog, double logBase, bool minorTick);
 
   virtual UpdateType update(int update_counter);
   virtual void save(QTextStream& ts, const QString& indent = QString::null);
   virtual void saveAttributes(QTextStream& ts, const QString& indent = QString::null);
-  
+
   virtual bool popupMenu(KPopupMenu *menu, const QPoint& pos, KstViewObjectPtr topLevelParent);
   virtual bool layoutPopupMenu(KPopupMenu *menu, const QPoint& pos, KstViewObjectPtr topLevelParent);
 
@@ -139,6 +144,9 @@ public:
   void pushPlotColors();
   void popPlotColors();
 
+  void updateScalars();
+  const QDict<KstScalar>& scalars() const;
+
   /** Set the scale */
   void setScale(double xmin, double ymin, double xmax, double ymax);
   /** Set the X scale */
@@ -378,12 +386,21 @@ public:
   KstViewLegendPtr legend() const;
 
   KstViewLegendPtr getOrCreateLegend();
-  
+
   virtual QRect contentsRect() const;
 
   double verticalSizeFactor();
   double horizontalSizeFactor();
-  
+
+  virtual void setTagName(const KstObjectTag& newTag);
+
+protected:
+  QDict<KstScalar> _scalars;
+
+  /** scalar maintenance methods */
+  void createScalars();
+  void renameScalars();
+
 signals:
   void modified();
 
@@ -391,8 +408,10 @@ public slots:
   void copy();
 
   virtual void edit();
+  virtual void deleteObject();
   virtual void copyObject();
   virtual KstViewObject* copyObjectQuietly(KstViewObject& parent, const QString& name = QString::null) const;
+  virtual KstViewObject* copyObjectQuietly() const;
   void draw(); // draw into back buffer
   void draw(KstPainter& p); // This actually does the drawing
   void paintSelf(KstPainter& p, const QRegion& bounds);
@@ -407,6 +426,8 @@ public slots:
   bool tiedZoomMode(ZoomType zoom, bool flag, double center, KstScaleModeType mode, KstScaleModeType modeExtra);
   void tiedZoom(bool x, double xmin, double xmax, bool y, double ymin, double ymax);
   void fitCurve(int id);
+  void fitCurveVisibleDynamic(int id);
+  void fitCurveVisibleStatic(int id);
   void filterCurve(int id);
   void removeCurve(int id);
 
@@ -471,7 +492,7 @@ private:
                          TickParameters &tpx,  TickParameters &tpy,
                          QPainter& p, bool& bOffsetX, bool& bOffsetY,
                          double xtick_len_px, double ytick_len_px);
-  void setTicks(double& tick, double& org,
+  void setTicks(double& tick, double& org, bool& labelMinor,
                 double max, double min, bool is_log, double logBase, bool isX, int base);
   double convertTimeValueToJD(KstAxisInterpretation axisInterpretation, double valueIn);
   double convertTimeDiffValueToDays(KstAxisInterpretation axisInterpretation, double diffIn);
@@ -490,7 +511,7 @@ private:
   void updateXYGuideline(QWidget *view, const QPoint& oldPos, const QPoint& newPos, const QRect& pr, KstMouseModeType gzType);
 
   // range and domain of plot: not plot dimentions
-  double XMin, XMax, YMin, YMax;
+  double _XMin, _XMax, _YMin, _YMax;
 
   double _copy_x, _copy_y;
   double _cursor_x, _cursor_y;
@@ -578,6 +599,7 @@ private:
   QRect _oldAlignment;
   double _m_X, _b_X, _m_Y, _b_Y;
   double _tickYLast, _stLast;
+  bool _labelMinorLast;
   int _autoTickYLast;
 
   QColor _colorMarkers;
@@ -598,10 +620,8 @@ private:
   int _reqYMinorTicks; // -1 means use auto
   int _xMinorTicks;
   int _yMinorTicks;
-
   int _xMajorTicks;
   int _yMajorTicks;
-  
   int _i_per; // index for next image color range
 
   KstPlotLabel *_xLabel, *_yLabel, *_topLabel, *_xTickLabel, *_yTickLabel, *_fullTickLabel;
