@@ -33,7 +33,8 @@ class KstCsdDialogI : public KstDataDialog {
     KST_EXPORT static KstCsdDialogI *globalInstance();
 
   protected:
-    QString objectName() { return tr("Spectrogram"); }
+    QString editTitle() { return tr("Edit Spectrogram"); }
+    QString newTitle() { return tr("New Spectrogram"); }
  
   public slots:
     /** update the entries in the psd dialog to represent current psds */
@@ -61,13 +62,15 @@ class KstCsdDialogI : public KstDataDialog {
     bool _rateUnitsDirty : 1;
     bool _outputDirty : 1;
     bool _windowSizeDirty : 1;
+    bool _interpolateHolesDirty : 1;
     bool editSingleObject(KstCSDPtr csPtr);
 
   private slots:
     void setApodizeDirty();
     void setRemoveMeanDirty();
     void setInterleavedDirty();
-    
+    void setInterpolateHolesDirty();
+
   private:
     static const QString& defaultTag;
     void fillFieldsForEdit();
