@@ -88,7 +88,7 @@ void KstDataDialog::showNew(const QString& field)
     _tagName->setEnabled(true);
     _legendText->setEnabled(true);
 
-    setCaption(i18n("New %1").arg(objectName()));
+    setCaption(newTitle());
     QDialog::show();
     raise();
     _ok->setEnabled(true);
@@ -119,7 +119,7 @@ void KstDataDialog::showEdit(const QString& field)
     update();
     fillFieldsForEdit();
 
-    setCaption(i18n("Edit %1").arg(objectName()));
+    setCaption(editTitle());
     QDialog::show();
     raise();
     _ok->setEnabled(true);
@@ -127,7 +127,13 @@ void KstDataDialog::showEdit(const QString& field)
 }
 
 
-QString KstDataDialog::objectName()
+QString KstDataDialog::editTitle()
+{
+    return QString::null;
+}
+
+
+QString KstDataDialog::newTitle()
 {
     return QString::null;
 }
