@@ -54,6 +54,7 @@
 #include "kstgraphfiledialog_i.h"
 #include "kstequation.h"
 #include "ksteventmonitorentry.h"
+#include "kstvectorview.h"
 #include "ksthistogram.h"
 #include "kstimage.h"
 #include "kstmatrixdefaults.h"
@@ -441,6 +442,10 @@ bool KstDoc::openDocument(const KURL& url, const QString& o_file,
         KstDataObjectPtr p = new KstCSD(e);
         KstWriteLocker dowl(&KST::dataObjectList.lock());
         KST::dataObjectList.append(p);
+      } else if (e.tagName() == "vectorview") {
+        KstDataObjectPtr p = new KstVectorView(e);
+        KstWriteLocker dowl(&KST::dataObjectList.lock());
+        KST::dataObjectList.append(p);
       } else if (e.tagName() == "histogram") {
         KstDataObjectPtr p = new KstHistogram(e);
         KstWriteLocker dowl(&KST::dataObjectList.lock());
@@ -889,7 +894,11 @@ void KstDoc::samplesUp() {
     int fileN = V->fileLength();
 
     bool didChange = false;
-    if (f0 + 2 * n > fileN) {
+
+    if (f0 == -1) {
+      didChange = true;
+      f0 = fileN - n;
+    } else if (f0 + 2 * n > fileN) {
       didChange = f0 != fileN - n;
       changed = changed || didChange;
       f0 = fileN - n;
