@@ -207,10 +207,10 @@ bool KstEqDialogI::newObject() {
   vc->setHasBars(_w->_curveAppearance->showBars());
   vc->setLineWidth(_w->_curveAppearance->lineWidth());
   vc->setLineStyle(_w->_curveAppearance->lineStyle());
-  vc->pointType = _w->_curveAppearance->pointType();
+  vc->setPointStyle(_w->_curveAppearance->pointType());
   vc->setPointDensity(_w->_curveAppearance->pointDensity());
   vc->setBarStyle(_w->_curveAppearance->barStyle());
-  
+
   QString legend_text = _legendText->text();
   if (legend_text == defaultTag) {
     vc->setLegendText(QString(""));
@@ -227,7 +227,7 @@ bool KstEqDialogI::newObject() {
   if (w) {
     Kst2DPlotPtr plot;
     if (_w->_curvePlacement->existingPlot()) {
-      /* assign curve to plot */
+      // assign curve to plot
       plot = kst_cast<Kst2DPlot>(w->view()->findChild(_w->_curvePlacement->plotName()));
       if (plot) {
         plot->addCurve(vc.data());
@@ -235,7 +235,7 @@ bool KstEqDialogI::newObject() {
     }
 
     if (_w->_curvePlacement->newPlot()) {
-      /* assign curve to plot */
+      // assign curve to plot
       QString name = w->createPlot(KST::suggestPlotName());
       if (_w->_curvePlacement->reGrid()) {
         w->view()->cleanup(_w->_curvePlacement->columns());
@@ -293,14 +293,14 @@ bool KstEqDialogI::editSingleObject(KstEquationPtr eqPtr) {
     vp = eqPtr->vX();
   }
   KST::vectorList.lock().unlock();
-  
+
   // update the DoInterpolation only if it is dirty
   if (_doInterpolationDirty) {
     eqPtr->setExistingXVector(vp, _w->_doInterpolation->isChecked());
   } else {
     eqPtr->setExistingXVector(vp, eqPtr->doInterp());
   }
-  
+
   if (_equationDirty) {
     eqPtr->setEquation(_w->_equation->text());
     if (!eqPtr->isValid()) {
@@ -311,23 +311,33 @@ bool KstEqDialogI::editSingleObject(KstEquationPtr eqPtr) {
       }
       KMessageBox::detailedSorry(this, i18n("There is an error in the equation you entered."), parseErrors);
       eqPtr->unlock();
+      return true;
+    }
+
+    eqPtr->setRecursed(false);
+    if (eqPtr->recursion()) {
+      eqPtr->setRecursed(true);
+      eqPtr->unlock();
+      KMessageBox::error(this, i18n("There is a recursion resulting from the equation you entered."));
       return false;
     }
   }
+
   eqPtr->unlock();
+
   return true;
 }
 
 
 bool KstEqDialogI::editObject() {
   KstEquationList eqList = kstObjectSubList<KstDataObject,KstEquation>(KST::dataObjectList);
-  
+
   // if editing multiple objects, edit each one
   if (_editMultipleMode) { 
     // if the user selected no vector, treat it as non-dirty
     _xVectorsDirty = _w->_xVectors->_vector->currentItem() != 0;
     _equationDirty = !_w->_equation->text().isEmpty();
-  
+
     bool didEdit = false;
     for (uint i = 0; i < _editMultipleWidget->_objectList->count(); i++) {
       if (_editMultipleWidget->_objectList->isSelected(i)) {
@@ -336,7 +346,7 @@ bool KstEqDialogI::editObject() {
         if (eqIter == eqList.end()) {
           return false;
         }
-          
+
         KstEquationPtr eqPtr = *eqIter;
         if (!editSingleObject(eqPtr)) {
           return false;
@@ -356,11 +366,11 @@ bool KstEqDialogI::editObject() {
       _tagName->setFocus();
       return false;
     }
-    
+
     ep->writeLock();
     ep->setTagName(tag_name);
     ep->unlock();
-    
+
     // then edit the object
     _equationDirty = true;
     _xVectorsDirty = true;
@@ -443,4 +453,4 @@ void KstEqDialogI::setDoInterpolationDirty() {
 }
 
 #include "ksteqdialog_i.moc"
-// vim: ts=2 sw=2 et
+
