@@ -146,7 +146,7 @@ bool KstFitDialogI::createCurve(KstCPluginPtr plugin) {
   fit->setHasBars(_w->_curveAppearance->showBars());
   fit->setLineWidth(_w->_curveAppearance->lineWidth());
   fit->setLineStyle(_w->_curveAppearance->lineStyle());
-  fit->pointType = _w->_curveAppearance->pointType();
+  fit->setPointStyle(_w->_curveAppearance->pointType());
   fit->setBarStyle(_w->_curveAppearance->barStyle());
   fit->setPointDensity(_w->_curveAppearance->pointDensity());
 
@@ -157,14 +157,14 @@ bool KstFitDialogI::createCurve(KstCPluginPtr plugin) {
     if (plot) {
       QString strLabel = QString("[%1]").arg(plugin->tagName());      
       KstViewLabelPtr label = new KstViewLabel();
-      
+
       label->setTransparent(true);
       label->resizeFromAspect(0.1, 0.1, 0.05, 0.05);
       label->setJustification(SET_KST_JUSTIFY(KST_JUSTIFY_H_CENTER, KST_JUSTIFY_V_CENTER));
-      
+
       plot->appendChild(KstViewObjectPtr(label), true);
       label->setText(strLabel);
-      
+
       plot->addCurve(KstBaseCurvePtr(fit));
     }
   }
@@ -239,7 +239,6 @@ bool KstFitDialogI::newObject() {
 
 
 void KstFitDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QGridLayout *grid, const QValueList<Plugin::Data::IOValue>& table) {
-
   const QString& pluginName = _pluginList[_w->PluginCombo->currentItem()];
   const Plugin::Data& pluginData = PluginCollection::self()->pluginList()[PluginCollection::self()->pluginNameList()[pluginName]];
   bool isWeighted = pluginData._isFitWeighted;
@@ -274,7 +273,8 @@ void KstFitDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QGrid
         string = true;
         break;
       case Plugin::Data::IOValue::TableType:
-        if (input && ( iInputVector < 2 || ( isWeighted && iInputVector < 3 ) ) ) {
+        if (input && ( iInputVector == 0 || iInputVector == 1 || 
+                     ( isWeighted && iInputVector == 2 && !_evector.isEmpty() ) ) ) {
           fixed = true;
         }
         if ((*it)._subType == Plugin::Data::IOValue::FloatSubType ||
@@ -435,4 +435,3 @@ bool KstFitDialogI::saveInputs(KstCPluginPtr plugin, KstSharedPtr<Plugin> p) {
 
 #include "kstfitdialog_i.moc"
 
-// vim: ts=2 sw=2 et
