@@ -229,7 +229,7 @@ bool KstHsDialogI::newObject() {
   vc->setHasPoints(_w->_curveAppearance->showPoints());
   vc->setHasLines(_w->_curveAppearance->showLines());
   vc->setHasBars(_w->_curveAppearance->showBars());
-  vc->pointType = _w->_curveAppearance->pointType();
+  vc->setPointStyle(_w->_curveAppearance->pointType());
   vc->setLineWidth(_w->_curveAppearance->lineWidth());
   vc->setLineStyle(_w->_curveAppearance->lineStyle());
   vc->setBarStyle(_w->_curveAppearance->barStyle());
@@ -250,7 +250,7 @@ bool KstHsDialogI::newObject() {
   if (w) {
     Kst2DPlotPtr plot;
     if (_w->_curvePlacement->existingPlot()) {
-      /* assign curve to plot */
+      // assign curve to plot
       plot = kst_cast<Kst2DPlot>(w->view()->findChild(_w->_curvePlacement->plotName()));
       if (plot) {
         plot->addCurve(vc.data());
@@ -258,7 +258,7 @@ bool KstHsDialogI::newObject() {
     }
 
     if (_w->_curvePlacement->newPlot()) {
-      /* assign curve to plot */
+      // assign curve to plot
       QString name = w->createPlot(KST::suggestPlotName());
       if (_w->_curvePlacement->reGrid()) {
         w->view()->cleanup(_w->_curvePlacement->columns());
@@ -355,6 +355,14 @@ bool KstHsDialogI::editSingleObject(KstHistogramPtr hsPtr) {
     }
   }
 
+  hsPtr->setRecursed(false);
+  if (hsPtr->recursion()) {
+    hsPtr->setRecursed(true);
+    hsPtr->unlock();
+    KMessageBox::error(this, i18n("There is a recursion resulting from the histogram you entered."));
+    return false;
+  }
+
   hsPtr->setDirty();
   hsPtr->unlock();
   return true;
@@ -518,4 +526,4 @@ void KstHsDialogI::setVector(const QString& name) {
 
 
 #include "ksthsdialog_i.moc"
-// vim: ts=2 sw=2 et
+
