@@ -616,6 +616,7 @@ bool KstPluginDialogI::editObject() {
   int pitem = _w->PluginCombo->currentItem();
   KstSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[pitem]);
 
+  pp->setRecursed(false);
   pp->inputVectors().clear();
   pp->inputScalars().clear();
   pp->inputStrings().clear();
@@ -639,9 +640,18 @@ bool KstPluginDialogI::editObject() {
     KMessageBox::sorry(this, i18n("There is an error in the plugin you entered."));
     return false;
   }
+
+  pp->setRecursed(false);
+  if (pp->recursion()) {
+    pp->setRecursed(true);
+    KMessageBox::sorry(this, i18n("There is a recursion resulting from the plugin you entered."));
+    return false;
+  }
+
   pp->setDirty();
 
   emit modified();
+
   return true;
 }
 
