@@ -61,7 +61,7 @@ KstPsdDialogI::KstPsdDialogI(QWidget* parent, const char* name, bool modal, WFla
   _w = new PSDDialogWidget(_contents);
   setMultiple(true);
   connect(_w->_vector, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
-  
+
   //for multiple edit mode
   connect(_w->_kstFFTOptions->Apodize, SIGNAL(clicked()), this, SLOT(setApodizeDirty()));
   connect(_w->_kstFFTOptions->RemoveMean, SIGNAL(clicked()), this, SLOT(setRemoveMeanDirty()));
@@ -193,7 +193,7 @@ bool KstPsdDialogI::newObject() {
     vc->setHasPoints(_w->_curveAppearance->showPoints());
     vc->setHasLines(_w->_curveAppearance->showLines());
     vc->setHasBars(_w->_curveAppearance->showBars());
-    vc->pointType = _w->_curveAppearance->pointType();
+    vc->setPointStyle(_w->_curveAppearance->pointType());
     vc->setLineWidth(_w->_curveAppearance->lineWidth());
     vc->setLineStyle(_w->_curveAppearance->lineStyle());
     vc->setBarStyle(_w->_curveAppearance->barStyle());
@@ -264,19 +264,19 @@ bool KstPsdDialogI::editSingleObject(KstPSDPtr psPtr) {
   // get the values that need to be checked for consistency
   double pSampRate;
   int pFFTLen;
-  
+
   if (_sampRateDirty) {
     pSampRate = _w->_kstFFTOptions->SampRate->text().toDouble();
   } else {
     pSampRate = psPtr->freq();
   }
-    
+
   if (_fFTLenDirty) {
     pFFTLen = _w->_kstFFTOptions->FFTLen->text().toInt();
   } else {
     pFFTLen = psPtr->len();
   }
-  
+
   if (!_w->_kstFFTOptions->checkGivenValues(pSampRate, pFFTLen)) {
     psPtr->unlock();
     return false;
@@ -285,7 +285,7 @@ bool KstPsdDialogI::editSingleObject(KstPSDPtr psPtr) {
   if (_sampRateDirty) {
     psPtr->setFreq(_w->_kstFFTOptions->SampRate->text().toDouble());
   }
-  
+
   if (_fFTLenDirty) {
     psPtr->setLen(_w->_kstFFTOptions->FFTLen->text().toInt());
   }
@@ -303,11 +303,15 @@ bool KstPsdDialogI::editSingleObject(KstPSDPtr psPtr) {
   }
 
   if (_apodizeFxnDirty) {
-    psPtr->setApodizeFxn(ApodizeFunction(_w->_kstFFTOptions->ApodizeFxn->currentItem()));
+    if (_editMultipleMode) {
+      psPtr->setApodizeFxn(ApodizeFunction(_w->_kstFFTOptions->ApodizeFxn->currentItem()-1));
+    } else {
+      psPtr->setApodizeFxn(ApodizeFunction(_w->_kstFFTOptions->ApodizeFxn->currentItem()));
+    }
   }
 
   if (_gaussianSigmaDirty) {
-    psPtr->setGaussianSigma(_editMultipleMode ? _w->_kstFFTOptions->Sigma->value() - 1 : 
+    psPtr->setGaussianSigma(_editMultipleMode ? _w->_kstFFTOptions->Sigma->value() - 1 :
                                                 _w->_kstFFTOptions->Sigma->value());
   }
 
@@ -320,13 +324,25 @@ bool KstPsdDialogI::editSingleObject(KstPSDPtr psPtr) {
   }
 
   if (_outputDirty) {
-    psPtr->setOutput(PSDType(_w->_kstFFTOptions->Output->currentItem()));
+    if (_editMultipleMode) {
+      psPtr->setOutput(PSDType(_w->_kstFFTOptions->Output->currentItem()-1));
+    } else {
+      psPtr->setOutput(PSDType(_w->_kstFFTOptions->Output->currentItem()));
+    }
   }
 
   if (_interpolateHolesDirty) {
     psPtr->setInterpolateHoles(_w->_kstFFTOptions->InterpolateHoles->isChecked());
   }
 
+  psPtr->setRecursed(false);
+  if (psPtr->recursion()) {
+    psPtr->setRecursed(true);
+    psPtr->unlock();
+    KMessageBox::error(this, i18n("There is a recursion resulting from the spectrum  you entered."));
+    return false;
+  }
+
   psPtr->unlock();
   return true;
 }
@@ -336,14 +352,14 @@ bool KstPsdDialogI::editSingleObject(KstPSDPtr psPtr) {
 bool KstPsdDialogI::editObject() {
   // if the user selected no vector, treat it as non-dirty
   _vectorDirty = _w->_vector->_vector->currentItem() != 0;
-  _apodizeDirty = _w->_kstFFTOptions->ApodizeFxn->currentItem() != 0;
+  _apodizeFxnDirty = _w->_kstFFTOptions->ApodizeFxn->currentItem() != 0;
   _fFTLenDirty = _w->_kstFFTOptions->FFTLen->text() != " ";
   _sampRateDirty = !_w->_kstFFTOptions->SampRate->text().isEmpty();
   _vectorUnitsDirty = !_w->_kstFFTOptions->VectorUnits->text().isEmpty();
   _rateUnitsDirty = !_w->_kstFFTOptions->RateUnits->text().isEmpty();
-  _outputDirty = !_w->_kstFFTOptions->Output->currentItem() != 0;
+  _outputDirty = _w->_kstFFTOptions->Output->currentItem() != 0;
   KstPSDList psList = kstObjectSubList<KstDataObject,KstPSD>(KST::dataObjectList);
-  
+
   // if editing multiple objects, edit each one
   if (_editMultipleMode) { 
     bool didEdit = false;
@@ -354,9 +370,9 @@ bool KstPsdDialogI::editObject() {
         if (psIter == psList.end()) {
           return false;
         }
-          
+
         KstPSDPtr psPtr = *psIter;
-        
+
         if (!editSingleObject(psPtr)) {
           return false;
         }
@@ -375,11 +391,11 @@ bool KstPsdDialogI::editObject() {
       _tagName->setFocus();
       return false;
     }
-    
+
     pp->writeLock();
     pp->setTagName(KstObjectTag(tag_name, pp->tag().context())); // FIXME: doesn't allow changing tag context
     pp->unlock();
-    
+
     // then edit the object
     _vectorDirty = true;
     _apodizeDirty = true;
@@ -426,7 +442,7 @@ void KstPsdDialogI::populateEditMultiple() {
   _w->_kstFFTOptions->Sigma->setValue(_w->_kstFFTOptions->Sigma->minValue());
   _w->_kstFFTOptions->Output->insertItem("", 0);
   _w->_kstFFTOptions->Output->setCurrentItem(0);
-  
+
   _tagName->setText("");
   _tagName->setEnabled(false);
 
@@ -490,4 +506,4 @@ void KstPsdDialogI::setVector(const QString& name) {
 }
 
 #include "kstpsddialog_i.moc"
-// vim: ts=2 sw=2 et
+
