@@ -198,9 +198,9 @@ void KstTopLevelView::updateFocus(const QPoint& pos) {
   if (_mode == DisplayMode || _mode == Unknown || tracking()) {
     return;
   }
-  
+
   //TODO: make this work better with click-select mode
-  
+
   KstViewObjectPtr p = findDeepestChild(pos, false);
   if (p) {
     KstViewObjectPtr p2 = p;
@@ -309,17 +309,17 @@ bool KstTopLevelView::handlePress(const QPoint& pos, bool shift) {
     _activeHandler->handlePress(this, pos, shift);
     return true;
   }
-  
+
   _mouseMoved = false;
-  
+
   //kstdDebug() << "HANDLE PRESS" << endl;
   _pressDirection = -1;
 
   if (_mode != LayoutMode) {
     _pressTarget = 0L;
     return false;
-  }  
-  
+  }
+
   _pressTarget = findDeepestChild(pos, false);
   if (_pressTarget) {
     KstViewObjectPtr p = _pressTarget;
@@ -351,9 +351,9 @@ bool KstTopLevelView::handlePress(const QPoint& pos, bool shift) {
   }
 
   assert(_pressTarget);
-  
+
   _pressDirection = _pressTarget->directionFor(pos);
-  
+
   if (shift && _pressDirection < 1) {
     KstViewObjectList::Iterator it = _selectionList.find(_pressTarget);
 
@@ -389,7 +389,7 @@ bool KstTopLevelView::handlePress(const QPoint& pos, bool shift) {
     _selectionList.clear();
     recursively<bool>(&KstViewObject::setSelected, false);
   }
-  
+
   // single click selects a single object if it is not part of the current list
   if (!_selectionList.contains(_pressTarget)) {
     _selectionList.clear();
@@ -430,16 +430,16 @@ QRect KstTopLevelView::newSize(const QRect& originalSize, const QRect& bounds, i
     anchor_pt.setX(originalSize.left());
   }
 
-  if ( ((direction & (UP|DOWN)) == 0) || ((direction & (LEFT|RIGHT)) == 0) ) { //resizing from edge.
+  if ((direction & (UP|DOWN)) == 0 || (direction & (LEFT|RIGHT)) == 0) { //resizing from edge.
     return KstGfxMouseHandlerUtils::resizeRectFromEdge(originalSize, anchor_pt, move_pt, npos, bounds, maintainAspect);
   } else { //resizing from corner.
-    return KstGfxMouseHandlerUtils::resizeRectFromCorner(anchor_pt, move_pt, npos, bounds,maintainAspect);
+    return KstGfxMouseHandlerUtils::resizeRectFromCorner(anchor_pt, move_pt, npos, bounds, maintainAspect);
   }
-
 }
 
 
-QRect KstTopLevelView::newSizeCentered(const QRect& oldSize, const QRect& bounds, const QPoint& pos, bool maintainAspect) {
+QRect KstTopLevelView::newSizeCentered(const QRect& originalSize, const QRect& bounds, int direction, const QPoint& pos, bool maintainAspect) {
+  QPoint anchor_pt, move_pt;
   QPoint npos = pos;
 
   npos.setX(kMax(npos.x(), bounds.left()));
@@ -447,7 +447,25 @@ QRect KstTopLevelView::newSizeCentered(const QRect& oldSize, const QRect& bounds
   npos.setY(kMin(npos.y(), bounds.bottom()));
   npos.setY(kMax(npos.y(), bounds.top()));
 
-  return KstGfxMouseHandlerUtils::resizeRectFromCornerCentered(oldSize, npos, bounds, maintainAspect);
+  anchor_pt = move_pt = originalSize.center();
+
+  if ((direction & UP) != 0) {
+    move_pt.setY(originalSize.top());
+  } else if ((direction & DOWN) != 0) {
+    move_pt.setY(originalSize.bottom());
+  }
+
+  if ((direction & LEFT) != 0) {
+    move_pt.setX(originalSize.left());
+  } else if ((direction & RIGHT) != 0) {
+    move_pt.setX(originalSize.right());
+  }
+
+  if ((direction & (UP|DOWN)) == 0 || (direction & (LEFT|RIGHT)) == 0) { //resizing from edge.
+    return KstGfxMouseHandlerUtils::resizeRectFromEdgeCentered(originalSize, anchor_pt, move_pt, npos, bounds, maintainAspect);
+  } else { //resizing from corner.
+    return KstGfxMouseHandlerUtils::resizeRectFromCornerCentered(originalSize, npos, bounds, maintainAspect);
+  }
 }
 
 
@@ -469,6 +487,7 @@ bool KstTopLevelView::tiedZoomPrev(const QString& plotName) {
 bool KstTopLevelView::tiedZoomMode(int zoom, bool flag, double center, int mode, int modeExtra, const QString& plotName) {
   Kst2DPlotList pl = findChildrenType<Kst2DPlot>(true);
   bool repaint = false;
+
   for (Kst2DPlotList::Iterator i = pl.begin(); i != pl.end(); ++i) {
     Kst2DPlotPtr p = *i;
     if (p->isTied() && p->tagName() != plotName) {
@@ -476,6 +495,7 @@ bool KstTopLevelView::tiedZoomMode(int zoom, bool flag, double center, int mode,
       repaint = true;
     }
   }
+
   return repaint;
 }
 
@@ -483,6 +503,7 @@ bool KstTopLevelView::tiedZoomMode(int zoom, bool flag, double center, int mode,
 bool KstTopLevelView::tiedZoom(bool x, double xmin, double xmax, bool y, double ymin, double ymax, const QString& plotName) {
   Kst2DPlotList pl = findChildrenType<Kst2DPlot>(true);
   bool repaint = false;
+
   for (Kst2DPlotList::Iterator i = pl.begin(); i != pl.end(); ++i) {
     Kst2DPlotPtr p = *i;
     if (p->isTied() && p->tagName() != plotName) {
@@ -490,17 +511,18 @@ bool KstTopLevelView::tiedZoom(bool x, double xmin, double xmax, bool y, double
       repaint = true;
     }
   }
+
   return repaint;
-} 
+}
 
 
 void KstTopLevelView::moveSnapToBorders(int *xMin, int *yMin, const KstViewObjectPtr &obj, const QRect &r) const {
   for (KstViewObjectList::ConstIterator i = obj->children().begin(); i != obj->children().end(); ++i) {
     if (_selectionList.find(*i) == _selectionList.end() && _pressTarget != *i) {
       const QRect rect((*i)->geometry());
-      
+
       moveSnapToBorders(xMin, yMin, *i, r);
-            
+
       int overlapLo = r.top() > rect.top() ? r.top() : rect.top();
       int overlapHi = r.bottom() < rect.bottom() ? r.bottom() : rect.bottom();
       if (overlapHi - overlapLo > 0) {
@@ -514,7 +536,7 @@ void KstTopLevelView::moveSnapToBorders(int *xMin, int *yMin, const KstViewObjec
           *xMin = r.right() - rect.right();
         }
       }
-  
+
       overlapLo = r.left() > rect.left() ? r.left() : rect.left();
       overlapHi = r.right() < rect.right() ? r.right() : rect.right();
       if (overlapHi - overlapLo > 0) {
@@ -537,9 +559,9 @@ void KstTopLevelView::resizeSnapToBorders(int *xMin, int *yMin, const KstViewObj
   for (KstViewObjectList::ConstIterator i = obj->children().begin(); i != obj->children().end(); ++i) {
     if (_pressTarget != *i) {
       const QRect rect((*i)->geometry());
-      
+
       resizeSnapToBorders(xMin, yMin, *i, r, direction);
-      
+
       int overlapLo = r.top() > rect.top() ? r.top() : rect.top();
       int overlapHi = r.bottom() < rect.bottom() ? r.bottom() : rect.bottom();
       if (overlapHi - overlapLo > 0) {
@@ -547,7 +569,7 @@ void KstTopLevelView::resizeSnapToBorders(int *xMin, int *yMin, const KstViewObj
           if (labs(r.left() - rect.left()) < labs(*xMin)) {
             *xMin = r.left() - rect.left();
           } else if (labs(r.left() - rect.right()) < labs(*xMin)) {
-            *xMin = r.left() - rect.right();              
+            *xMin = r.left() - rect.right();
           }
         } else if (direction & RIGHT) {
           if (labs(r.right() - rect.left()) < labs(*xMin)) {
@@ -555,7 +577,7 @@ void KstTopLevelView::resizeSnapToBorders(int *xMin, int *yMin, const KstViewObj
           } else if (labs(r.right() - rect.right()) < labs(*xMin)) {
             *xMin = r.right() - rect.right();
           }
-        }                 
+        }
       }
 
       overlapLo = r.left() > rect.left() ? r.left() : rect.left();
@@ -565,7 +587,7 @@ void KstTopLevelView::resizeSnapToBorders(int *xMin, int *yMin, const KstViewObj
           if (labs(r.top() - rect.top()) < labs(*yMin)) {
             *yMin = r.top() - rect.top();
           } else if (labs(r.top() - rect.bottom()) < labs(*yMin)) {
-            *yMin = r.top() - rect.bottom();              
+            *yMin = r.top() - rect.bottom();
           }
         } else if (direction & DOWN) {
           if (labs(r.bottom() - rect.top()) < labs(*yMin)) {
@@ -580,11 +602,96 @@ void KstTopLevelView::resizeSnapToBorders(int *xMin, int *yMin, const KstViewObj
 }
 
 
+void KstTopLevelView::pointSnapToBorders(int *xMin, int *yMin, const KstViewObjectPtr &obj, const QPoint &p) const {
+  for (KstViewObjectList::ConstIterator i = obj->children().begin(); i != obj->children().end(); ++i) {
+    if (_pressTarget != *i) {
+      const QRect rect((*i)->geometry());
+
+      pointSnapToBorders(xMin, yMin, *i, p);
+
+      if (rect.top() <= p.y() && rect.bottom() >= p.y()) {
+        if (labs(p.x() - rect.left()) < labs(*xMin)) {
+          *xMin = p.x() - rect.left();
+        } else if (labs(p.x() - rect.right()) < labs(*xMin)) {
+          *xMin = p.x() - rect.right();
+        }
+      }
+
+      if (rect.left() <= p.x() && rect.right() >= p.x()) {
+        if (labs(p.y() - rect.top()) < labs(*yMin)) {
+          *yMin = p.y() - rect.top();
+        } else if (labs(p.y() - rect.bottom()) < labs(*yMin)) {
+          *yMin = p.y() - rect.bottom();
+        }
+      }
+    }
+  }
+}
+
+
+QPoint KstTopLevelView::pointSnapToObjects(const QPoint& p) {
+  QRect rectNew;
+  QRect r;
+  int xMin = STICKY_THRESHOLD;
+  int yMin = STICKY_THRESHOLD;
+
+  r.setTopLeft(QPoint(0, 0));
+  r.setBottomRight(p);
+
+  pointSnapToBorders(&xMin, &yMin, this, p);
+
+  if (labs(yMin) < STICKY_THRESHOLD) {
+    r.setBottom(r.bottom() - yMin);
+  }
+
+  if (labs(xMin) < STICKY_THRESHOLD) {
+    r.setRight(r.right() - xMin);
+  }
+
+  return r.bottomRight();
+}
+
+
+QRect KstTopLevelView::resizeCenteredSnapToObjects(const QRect& r, const QRect& bounds, int direction) {
+  QRect rectNew = r;
+  int xMin = STICKY_THRESHOLD;
+  int yMin = STICKY_THRESHOLD;
+
+  resizeSnapToBorders(&xMin, &yMin, this, r, direction);
+
+  if (labs(yMin) < STICKY_THRESHOLD) {
+    if (direction & UP) {
+      rectNew.setTop(r.top() - yMin);
+      rectNew.setBottom(r.bottom() + yMin);
+    } else if (direction & DOWN) {
+      rectNew.setBottom(r.bottom() - yMin);
+      rectNew.setTop(r.top() + yMin);
+    }
+  }
+
+  if (labs(xMin) < STICKY_THRESHOLD) {
+    if (direction & LEFT) {
+      rectNew.setLeft(r.left() - xMin);
+      rectNew.setRight(r.right() + xMin);
+    } else if (direction & RIGHT) {
+      rectNew.setRight(r.right() - xMin);
+      rectNew.setLeft(r.left() + xMin);
+    }
+  }
+
+  if (!bounds.contains(rectNew)) {
+    rectNew = r;
+  }
+
+  return rectNew.normalize();
+}
+
+
 QRect KstTopLevelView::resizeSnapToObjects(const QRect& r, int direction) {
   QRect rectNew = r;
   int xMin = STICKY_THRESHOLD;
   int yMin = STICKY_THRESHOLD;
-  
+
   resizeSnapToBorders(&xMin, &yMin, this, r, direction);
 
   if (labs(yMin) < STICKY_THRESHOLD) {
@@ -594,15 +701,15 @@ QRect KstTopLevelView::resizeSnapToObjects(const QRect& r, int direction) {
       rectNew.setBottom(r.bottom() - yMin);
     }
   }
- 
+
   if (labs(xMin) < STICKY_THRESHOLD) {
     if (direction & LEFT) {
       rectNew.setLeft(r.left() - xMin);
-     } else if (direction & RIGHT) {
+    } else if (direction & RIGHT) {
       rectNew.setRight(r.right() - xMin);
     }
   }
- 
+
   return rectNew.normalize();
 }
 
@@ -626,18 +733,18 @@ static void slideInto(const QRect& region, QRect& obj) {
 }
 
 
-void KstTopLevelView::pressMove(const QPoint& pos, bool shift) {
+void KstTopLevelView::pressMove(const QPoint& pos, bool shift, bool alt) {
   if (_activeHandler) {
     _activeHandler->pressMove(this, pos, shift, _geom);  
     return;
   }
-  
+
   // in these cases there is nothing to do         
   if (_mode == DisplayMode || _mode == Unknown) {
     _pressTarget = 0L;
     return;
   }
-  
+
   if (_pressDirection == -1 && _pressTarget) { // menu released
     return;
   }
@@ -645,44 +752,47 @@ void KstTopLevelView::pressMove(const QPoint& pos, bool shift) {
   if (shift && _moveOffset == QPoint(-1, -1) && _pressDirection < 1) {
     return;
   }
-  
+
   _mouseMoved = true;
-  
+
   // handle as in layout mode
-  pressMoveLayoutMode(pos, shift);
+  pressMoveLayoutMode(pos, shift, alt);
 }
 
 
-void KstTopLevelView::pressMoveLayoutMode(const QPoint& pos, bool shift) {
+void KstTopLevelView::pressMoveLayoutMode(const QPoint& pos, bool shift, bool alt) {
   if (_pressTarget) {
+    bool snapToBorder = !alt;
+
     if (_pressDirection == 0) {
       // moving an object
-      pressMoveLayoutModeMove(pos, shift);
+      pressMoveLayoutModeMove(pos, shift, snapToBorder);
       KstApp::inst()->slotUpdateDataMsg(i18n("(x0,y0)-(x1,y1)", "(%1,%2)-(%3,%4)").arg(_prevBand.topLeft().x()).arg(_prevBand.topLeft().y()).arg(_prevBand.bottomRight().x()).arg(_prevBand.bottomRight().y()));
     } else if (_pressTarget->isResizable()) {
       bool maintainAspect = shift ^ _pressTarget->maintainAspect(); // if default behaviour is to maintainAspect on resize, then shift will now have opposite behaviour.
+
       if (_pressDirection & ENDPOINT) {
         // moving an endpoint of an object
-        pressMoveLayoutModeEndPoint(pos, maintainAspect);
+        pressMoveLayoutModeEndPoint(pos, maintainAspect, snapToBorder);
       } else if (_pressDirection & CENTEREDRESIZE) {
         // resizing an object with fixed center
-        pressMoveLayoutModeCenteredResize(pos, maintainAspect);
+        pressMoveLayoutModeCenteredResize(pos, maintainAspect, snapToBorder);
       } else {
         // resizing a rectangular object
-        pressMoveLayoutModeResize(pos, maintainAspect);
+        pressMoveLayoutModeResize(pos, maintainAspect, snapToBorder);
       }
       KstApp::inst()->slotUpdateDataMsg(i18n("(x0,y0)-(x1,y1)", "(%1,%2)-(%3,%4)").arg(_prevBand.topLeft().x()).arg(_prevBand.topLeft().y()).arg(_prevBand.bottomRight().x()).arg(_prevBand.bottomRight().y()));
     }
   } else {
     // selecting objects
-    pressMoveLayoutModeSelect(pos, shift);
-  }  
+    pressMoveLayoutModeSelect(pos);
+  }
 }
 
 
-void KstTopLevelView::pressMoveLayoutModeMove(const QPoint& pos, bool shift) {
+void KstTopLevelView::pressMoveLayoutModeMove(const QPoint& pos, bool shift, bool snapToBorder) {
   Q_UNUSED(shift)
-  
+
   const QRect old(_prevBand);
 
   QRect r(_pressTarget->geometry());
@@ -693,23 +803,24 @@ void KstTopLevelView::pressMoveLayoutModeMove(const QPoint& pos, bool shift) {
   QPoint topLeft(pos - _moveOffset - _pressTarget->geometry().topLeft() + r.topLeft());
   r.moveTopLeft(topLeft);
   _moveOffsetSticky = QPoint(0, 0);
-      
-  int xMin = STICKY_THRESHOLD;
-  int yMin = STICKY_THRESHOLD;
-  
-  moveSnapToBorders(&xMin, &yMin, this, r); 
-  
-  if (labs(xMin) < STICKY_THRESHOLD) {
-    _moveOffsetSticky.setX(xMin);
-    topLeft.setX(topLeft.x() - xMin);
-  }
-  
-  if (labs(yMin) < STICKY_THRESHOLD) {
-    _moveOffsetSticky.setY(yMin);
-    topLeft.setY(topLeft.y() - yMin);
-  } 
 
-  r.moveTopLeft(topLeft);      
+  if (snapToBorder) {
+    int xMin = STICKY_THRESHOLD;
+    int yMin = STICKY_THRESHOLD;
+
+    moveSnapToBorders(&xMin, &yMin, this, r); 
+
+    if (labs(xMin) < STICKY_THRESHOLD) {
+      _moveOffsetSticky.setX(xMin);
+      topLeft.setX(topLeft.x() - xMin);
+    }
+
+    if (labs(yMin) < STICKY_THRESHOLD) {
+      _moveOffsetSticky.setY(yMin);
+      topLeft.setY(topLeft.y() - yMin);
+    }
+    r.moveTopLeft(topLeft);
+  }
 
   if (!_geom.contains(r, true)) {
     slideInto(_geom, r);
@@ -717,13 +828,13 @@ void KstTopLevelView::pressMoveLayoutModeMove(const QPoint& pos, bool shift) {
   _prevBand = r;
   if (_prevBand != old) {
     KstPainter p;
-        
+
     p.begin(_w);
     p.setRasterOp(Qt::NotROP);
     p.setPen(QPen(Qt::black, 0, Qt::DotLine));
     if (_selectionList.isEmpty()) {
       if (old.topLeft() != QPoint(-1, -1)) {
-        _pressTarget->drawShadow(p, old.topLeft());  
+        _pressTarget->drawShadow(p, old.topLeft());
       }
       _pressTarget->drawShadow(p, r.topLeft());
     } else {
@@ -734,18 +845,39 @@ void KstTopLevelView::pressMoveLayoutModeMove(const QPoint& pos, bool shift) {
         (*iter)->drawShadow(p, r.topLeft() + (*iter)->geometry().topLeft() - originalTopLeft);
       }
     }
+
+    //
+    // draw a selection for the new parent if the _pressTarget is released now...
+    //
+    KstViewObjectPtr container = findDeepestChild(r);
+
+    if (container != _prevContainer) {
+      if (_prevContainer) {
+        _prevContainer->drawShadow(p, _prevContainer->geometry().topLeft());
+      }
+      if (container) {
+        container->drawShadow(p, container->geometry().topLeft());
+      }
+      _prevContainer = container;
+    }
+
     p.end();
   }
 }
 
 
-void KstTopLevelView::pressMoveLayoutModeResize(const QPoint& pos, bool maintainAspect) {
+void KstTopLevelView::pressMoveLayoutModeResize(const QPoint& pos, bool maintainAspect, bool snapToBorders) {
   const QRect old(_prevBand);
 
   _prevBand = newSize(_pressTarget->geometry(), _pressTarget->_parent->geometry(), _pressDirection, pos, maintainAspect);
+
+  if (snapToBorders) {
+    _prevBand = resizeSnapToObjects(_prevBand, _pressDirection); 
+  }
+
   if (_prevBand != old) {
     KstPainter p;
-        
+
     p.begin(_w);
     p.setRasterOp(Qt::NotROP);
     p.setPen(QPen(Qt::black, 0, Qt::DotLine));
@@ -758,9 +890,7 @@ void KstTopLevelView::pressMoveLayoutModeResize(const QPoint& pos, bool maintain
 }
 
 
-void KstTopLevelView::pressMoveLayoutModeSelect(const QPoint& pos, bool shift) {
-  Q_UNUSED(shift)
-  
+void KstTopLevelView::pressMoveLayoutModeSelect(const QPoint& pos) {
   const QRect old(_prevBand);
   QRect r;
   r.setTopLeft(_moveOffset);
@@ -778,10 +908,7 @@ void KstTopLevelView::pressMoveLayoutModeSelect(const QPoint& pos, bool shift) {
 }
 
 
-void KstTopLevelView::pressMoveLayoutModeEndPoint(const QPoint& pos, bool maintainAspect) {
-  // FIXME: remove this!!  Should not know about any specific type
-  // for now we only know how to deal with lines 
-
+void KstTopLevelView::pressMoveLayoutModeEndPoint(const QPoint& pos, bool maintainAspect, bool snapToBorder) {
   const QRect bounds(_pressTarget->_parent->geometry());
 
   if (KstViewLinePtr line = kst_cast<KstViewLine>(_pressTarget)) {
@@ -802,7 +929,7 @@ void KstTopLevelView::pressMoveLayoutModeEndPoint(const QPoint& pos, bool mainta
     } else {
       return;
     }
-    
+
     if (maintainAspect) {
       movePoint = KstGfxMouseHandlerUtils::findNearestPtOnLine(anchorPoint, movePoint, pos, bounds);
     } else {
@@ -813,6 +940,10 @@ void KstTopLevelView::pressMoveLayoutModeEndPoint(const QPoint& pos, bool mainta
       }
     }
 
+    if (snapToBorder) {
+      movePoint = pointSnapToObjects(movePoint); 
+    }
+
     const QRect old(_prevBand);
     _prevBand.setTopLeft(*fromPoint);
     _prevBand.setBottomRight(*toPoint);
@@ -832,11 +963,15 @@ void KstTopLevelView::pressMoveLayoutModeEndPoint(const QPoint& pos, bool mainta
 }
 
 
-void KstTopLevelView::pressMoveLayoutModeCenteredResize(const QPoint& pos, bool maintainAspect) {
+void KstTopLevelView::pressMoveLayoutModeCenteredResize(const QPoint& pos, bool maintainAspect, bool snapToBorder) {
   //centered resize means that the center of the object stays constant
   const QRect old(_prevBand);
-  
-  _prevBand = newSizeCentered(_pressTarget->geometry(), _pressTarget->_parent->geometry(), pos, maintainAspect);
+
+  _prevBand = newSizeCentered(_pressTarget->geometry(), _pressTarget->_parent->geometry(), _pressDirection, pos, maintainAspect);
+
+  if (snapToBorder) {
+    _prevBand = resizeCenteredSnapToObjects(_prevBand, _pressTarget->_parent->geometry(), _pressDirection); 
+  }
 
   if (_prevBand != old) {
     KstPainter p;
@@ -869,11 +1004,17 @@ void KstTopLevelView::releasePressLayoutMode(const QPoint& pos, bool shift) {
       // we are resizing rectangular object(s)
       releasePressLayoutModeResize(pos, shift);
     }
-    _pressTarget->setFocus(true);   
-  } else { 
+
+    if (_pressTarget->parent()) {
+      _pressTarget->parent()->invalidateClipRegion();
+    }
+
+    _pressTarget->setFocus(true);
+  } else {
     // selecting objects using rubber band
     releasePressLayoutModeSelect(pos, shift);
   }
+  _prevContainer = 0L;
   _pressTarget = 0L;
   _pressDirection = -1;
   _moveOffset = QPoint(-1, -1);
@@ -891,7 +1032,7 @@ void KstTopLevelView::releasePressLayoutModeMove(const QPoint& pos, bool shift)
   if (!_selectionList.isEmpty()) {
     for (KstViewObjectList::ConstIterator i = _selectionList.begin(); i != _selectionList.end(); ++i) {
       obj = obj.unite((*i)->geometry());
-    } 
+    }
   }
   const QPoint objOffset(old.topLeft() - obj.topLeft());
 
@@ -902,17 +1043,20 @@ void KstTopLevelView::releasePressLayoutModeMove(const QPoint& pos, bool shift)
   }
 
   // This is not entirely correct.  findDeepestChild could actually return an
-  // object inside the selection list or even presstarget.  We should get
+  // object inside the selection list or even _pressTarget.  We should get
   // something that includes none of those.  This is most likely the parent of
   // the returned object in that case.
   KstViewObjectPtr container = findDeepestChild(obj);
   bool updateViewManager = false;
-  
+
   if (!container) {
     container = this;
   }
   if (container != _pressTarget && !container->children().contains(_pressTarget)) {
-    _pressTarget->detach();
+    if (_pressTarget->parent()) {
+      _pressTarget->parent()->invalidateClipRegion();
+      _pressTarget->detach();
+    }
     container->appendChild(_pressTarget);
     updateViewManager = true;
   }
@@ -928,10 +1072,11 @@ void KstTopLevelView::releasePressLayoutModeMove(const QPoint& pos, bool shift)
       thisObj->move(_pressTarget->position() + thisObj->geometry().topLeft() - old.topLeft());
     }
   }
-  
+
   if (updateViewManager) {
     KstApp::inst()->updateViewManager(true);
   }
+
   _onGrid = false;
 }
 
@@ -939,7 +1084,7 @@ void KstTopLevelView::releasePressLayoutModeMove(const QPoint& pos, bool shift)
 void KstTopLevelView::releasePressLayoutModeResize(const QPoint& pos, bool shift) {
   Q_UNUSED(pos)
   Q_UNUSED(shift)
-  
+
   if (_prevBand.topLeft() != QPoint(-1, -1)) {
     _prevBand = _prevBand.normalize();
     _pressTarget->move(_prevBand.topLeft());
@@ -951,9 +1096,9 @@ void KstTopLevelView::releasePressLayoutModeResize(const QPoint& pos, bool shift
 
 void KstTopLevelView::releasePressLayoutModeSelect(const QPoint& pos, bool shift) {
   Q_UNUSED(pos)
-  
+
   KstPainter p;
-    
+
   p.begin(_w);
   p.setRasterOp(Qt::NotROP);
   p.drawWinFocusRect(_prevBand);
@@ -1001,9 +1146,9 @@ void KstTopLevelView::releasePressLayoutModeEndPoint(const QPoint& pos, bool shi
 void KstTopLevelView::releasePressLayoutModeCenteredResize(const QPoint& pos, bool shift) {
   Q_UNUSED(pos)
   Q_UNUSED(shift)
-      
-  if (_prevBand.topLeft() != QPoint(-1, -1)) {    
-    _prevBand = _prevBand.normalize();    
+
+  if (_prevBand.topLeft() != QPoint(-1, -1)) {
+    _prevBand = _prevBand.normalize();
     _pressTarget->move(_prevBand.topLeft());
     _pressTarget->resize(_prevBand.size());
   }
@@ -1016,7 +1161,7 @@ void KstTopLevelView::releasePress(const QPoint& pos, bool shift) {
     _activeHandler->releasePress(this, pos, shift);
     return;
   }
-  
+
   // in these cases nothing should be done
   if (_mode == DisplayMode || _mode == Unknown) {
     _pressTarget = 0L;
@@ -1034,7 +1179,7 @@ void KstTopLevelView::releasePress(const QPoint& pos, bool shift) {
   releasePressLayoutMode(pos, shift);
 
   updateFocus(pos);
-  
+
   paint(KstPainter::P_PAINT);
 }
 
@@ -1095,7 +1240,7 @@ bool KstTopLevelView::popupMenu(KPopupMenu *menu, const QPoint& pos) {
       KPopupMenu *subMenu;
       int         numPlots = 0;
       int         id;
-      
+
       for (KstViewObjectList::ConstIterator i = _selectionList.begin(); i != _selectionList.end(); ++i) {
         if (kst_cast<Kst2DPlot>(*i)) {
           numPlots++;
@@ -1111,7 +1256,7 @@ bool KstTopLevelView::popupMenu(KPopupMenu *menu, const QPoint& pos) {
       if (numPlots < 2) {
         menu->setItemEnabled(id, false);
       }
-      
+
       subMenu = new KPopupMenu(menu);
       subMenu->insertItem(i18n("Width"), this, SLOT(makeSameWidth()));
       subMenu->insertItem(i18n("Height"), this, SLOT(makeSameHeight()));
@@ -1164,7 +1309,7 @@ void KstTopLevelView::condenseXAxis() {
     QRect geomItem;
     bool processed = false;
     const double close = 0.02;
-    
+
     // create a list of all plot objects in this view
     plots = kstObjectSubList<KstViewObject, Kst2DPlot>(_selectionList);
 
@@ -1179,11 +1324,11 @@ void KstTopLevelView::condenseXAxis() {
       // find all the plots that are attached to this one
       while (added && plots.count() > 0) {
         added = false;
-        
+
         for (Kst2DPlotList::ConstIterator i = plots.begin(); i != plots.end(); ++i) {
           aspectItem = (*i)->aspectRatio();
           geomItem = (*i)->geometry();
-          
+
           if ((geomItem.left() == geom.left() && geomItem.right() == geom.right()) ||
               (fabs(aspectItem.x - aspect.x) < close && fabs(aspectItem.w - aspect.w) < close)) {
             if (geom.top() - geomItem.bottom() == 1) {
@@ -1210,10 +1355,10 @@ void KstTopLevelView::condenseXAxis() {
             }
           }
         }
-        
+
         if (added) {
           geom = geom.unite(geomItem);
-          
+
           if (aspect.y < aspectItem.y) {
             aspect.y = aspectItem.y;
           }
@@ -1222,27 +1367,27 @@ void KstTopLevelView::condenseXAxis() {
           }
         }
       }
-      
+
       // modify the plot properties appropriately
       if (plotsProcess.count() > 1) {
         plotsProcess.first()->setSuppressTop(true);
         plotsProcess.first()->setDirty();
         plotsProcess.pop_front();
-        
+
         plotsProcess.last()->setSuppressBottom(true);
         plotsProcess.last()->setDirty();
         plotsProcess.pop_back();
-        
+
         for (Kst2DPlotList::Iterator i = plotsProcess.begin(); i != plotsProcess.end(); ++i) {
           (*i)->setSuppressTop(true);
           (*i)->setSuppressBottom(true);
           (*i)->setDirty();  
         }
-        
+
         processed = true;
       }
     }
-    
+
     if (processed) {
       widget()->paint(QRegion());
     }
@@ -1261,7 +1406,7 @@ void KstTopLevelView::condenseYAxis() {
     QRect geomItem;
     bool processed = false;
     const double close = 0.02;
-    
+
     // create a list of all plot objects
     plots = kstObjectSubList<KstViewObject, Kst2DPlot>(_selectionList);
 
@@ -1276,11 +1421,11 @@ void KstTopLevelView::condenseYAxis() {
       // find all the plots that are attached to this one
       while (added && plots.count() > 0) {
         added = false;
-        
+
         for (Kst2DPlotList::ConstIterator i = plots.begin(); i != plots.end(); ++i) {
           aspectItem = (*i)->aspectRatio();
           geomItem = (*i)->geometry();
-          
+
           if ((geomItem.top() == geom.top() && geomItem.bottom() == geom.bottom()) ||
               (fabs(aspectItem.y - aspect.y) < close && fabs(aspectItem.h - aspect.h) < close)) {
             if (geom.left() - geomItem.right() == 1) {
@@ -1306,10 +1451,10 @@ void KstTopLevelView::condenseYAxis() {
             }
           }
         }
-        
+
         if (added) {
           geom = geom.unite(geomItem);
-          
+
           if (aspect.x < aspectItem.x) {
             aspect.x = aspectItem.x;
           }
@@ -1318,23 +1463,23 @@ void KstTopLevelView::condenseYAxis() {
           }
         }
       }
-      
+
       // modify the plot properties appropriately
       if (plotsProcess.count() > 1) {
         plotsProcess.first()->setSuppressLeft(true);
         plotsProcess.first()->setDirty();
         plotsProcess.pop_front();
-        
+
         plotsProcess.last()->setSuppressRight(true);
         plotsProcess.last()->setDirty();
         plotsProcess.pop_back();
-                
+
         for (Kst2DPlotList::Iterator i = plotsProcess.begin(); i != plotsProcess.end(); ++i) {
           (*i)->setSuppressLeft(true);
           (*i)->setSuppressRight(true);
           (*i)->setDirty();
         }
-        
+
         processed = true;
       }
     }
@@ -1614,9 +1759,10 @@ void KstTopLevelView::cancelMouseOperations() {
     }
     //_pressTarget = 0L;
     _prevBand = QRect(-1, -1, 0, 0);
+    _prevContainer = 0L;
     return;
   }
-  
+
   // other graphics modes - delete the current drawing object
   if (_activeHandler) {
     _activeHandler->cancelMouseOperations(this);  
@@ -1649,26 +1795,23 @@ KstViewWidget *KstTopLevelView::widget() const {
 
 void KstTopLevelView::cleanupDefault() {
   // roughly layout in a square
-  cleanup();
+  cleanup(-1);
 }
 
 
 void KstTopLevelView::cleanupCustom() {
   bool ok = false;
+
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
   int numCols = KInputDialog::getInteger(i18n("Number of Columns"), 
                                          i18n("Select number of columns:"), 
                                          int(sqrt(_children.count())), 
-                                         1, 
-                                         _children.count(), 
-                                         1, 
-                                         &ok, 
-                                         0L);
+                                         1, _children.count(), 1, &ok, 0L);
   if (ok) {
     cleanup(numCols);
-  } 
+  }
 #else
-  for (;;) { 
+  for (;;) {
     QString numColsString = KLineEditDlg::getText(i18n("Enter number of columns:"), i18n("Number of Columns"), &ok, 0L);
     if (ok) {
       unsigned int numCols = numColsString.toInt();
@@ -1676,6 +1819,7 @@ void KstTopLevelView::cleanupCustom() {
         KMessageBox::sorry(KstApp::inst(), i18n("Enter a number of columns between 1 and %d").arg(_selectionList.count()));
       } else {
         cleanup(numCols);
+
         break;
       }
     } else {
@@ -1700,13 +1844,17 @@ void KstTopLevelView::release() {
 
 
 QSize KstTopLevelView::averageChildSize() const {
-  int widths = 0, heights = 0;
+  int widths = 0;
+  int heights = 0;
+  int c;
+
   for (KstViewObjectList::ConstIterator i = _children.begin(); i != _children.end(); ++i) {
     const QRect g((*i)->geometry());
     widths += g.width();
     heights += g.height();
   }
-  int c = _children.count();
+  c = _children.count();
+
   return c > 0 ? QSize(widths / c, heights / c) : QSize(0, 0);
 }
 
@@ -1719,11 +1867,20 @@ void KstTopLevelView::saveDefaults(KstViewObjectPtr object) {
 }
 
 
+void KstTopLevelView::restoreDefaults(KstViewObjectPtr object) {
+  KstGfxMouseHandler *handler = handlerForObject(object->type());
+  if (handler) {
+    handler->restoreDefaults();
+  }
+}
+
+
 bool KstTopLevelView::handleDoubleClick(const QPoint& pos, bool shift) {
   handlePress(pos, shift);
   if (_pressTarget) {
     _pressTarget->showDialog(this, false);  
-  }  
+  }
+
   return true;
 }
 
@@ -1731,7 +1888,9 @@ bool KstTopLevelView::handleDoubleClick(const QPoint& pos, bool shift) {
 void KstTopLevelView::deleteSelectedObjects() {
   for (KstViewObjectList::Iterator i = _selectionList.begin(); i != _selectionList.end(); ++i) {
     KstViewObjectPtr selection = *i;
+
     if (selection && selection->parent()) {
+      selection->parent()->invalidateClipRegion();
       selection->parent()->removeChild(selection);
     }
   }
@@ -1745,18 +1904,21 @@ void KstTopLevelView::deleteSelectedObjects() {
 QRect KstTopLevelView::correctWidthForRatio(const QRect& oldRect, double ratio, int direction) {
   QRect r = oldRect;
   if (direction & (UP|DOWN)) {
-    int negOne;
-    if (r.width() == 0) {
-      negOne = 1;  
-    } else {
-      negOne = r.width()/abs(r.width());  
-    }
     int newWidth;
-    if (ratio == 0) {
-      newWidth = abs(r.width());  
+    int negOne;
+
+    if (r.width() == 0) {
+      negOne = 1;
+    } else {
+      negOne = r.width()/abs(r.width());
+    }
+
+    if (ratio == 0.0) {
+      newWidth = abs(r.width());
     } else {
       newWidth = (int)(abs(r.height())/ratio);
     }
+
     if (direction & LEFT) {
       r.setLeft(r.right() - negOne * newWidth);  
     } else if (direction & RIGHT) {
@@ -1764,24 +1926,26 @@ QRect KstTopLevelView::correctWidthForRatio(const QRect& oldRect, double ratio,
     } else {
       r.setLeft((_pressTarget->geometry().left() + _pressTarget->geometry().right())/2 - negOne*newWidth/2);
       r.setRight(r.left() + negOne*newWidth);
-    }  
+    }
   }
+
   return r;
 }
 
 
 QRect KstTopLevelView::correctHeightForRatio(const QRect& oldRect, double ratio, int direction, int origRight, int origLeft) {
   QRect r = oldRect;
+
   if (direction & (LEFT|RIGHT)) {
     int newHeight = (int)(abs(r.width())*ratio);
     int negOne, negOneW;
     if (r.height() == 0) {
-      negOne = 1;  
+      negOne = 1;
     } else {
       negOne = r.height()/abs(r.height());  
     }
     if (r.width() == 0) {
-      negOneW = 1;  
+      negOneW = 1;
     } else {
       negOneW = r.width()/abs(r.width());
     }
@@ -1817,13 +1981,14 @@ QRect KstTopLevelView::correctHeightForRatio(const QRect& oldRect, double ratio,
         } else {
           r.setLeft(origLeft);
           r.setRight(origRight);  
-        } 
+        }
       }
     } else {
       r.setTop((_pressTarget->geometry().top() + _pressTarget->geometry().bottom())/2 - negOne*newHeight/2);
       r.setBottom(r.top() + negOne*newHeight);
-    }  
+    }
   }
+
   return r;
 }
 
@@ -1838,8 +2003,9 @@ KstGfxMouseHandler *KstTopLevelView::handlerForObject(const QString& objType) {
   if (rc) {
     _handlers[objType] = rc;
   }
+
   return rc;
 }
 
 #include "ksttoplevelview.moc"
-// vim: ts=2 sw=2 et
+
