@@ -31,6 +31,7 @@
 
 KstViewBox::KstViewBox()
 : KstViewObject("Box"), _borderColor(QColor(0, 0, 0)), _borderWidth(0) {
+  _editTitle = i18n("Edit Box");
   _xRound = 0;
   _yRound = 0;
   _cornerStyle = Qt::MiterJoin;
@@ -44,20 +45,21 @@ KstViewBox::KstViewBox()
 
 KstViewBox::KstViewBox(const QDomElement& e)
 : KstViewObject(e), _borderColor(QColor(0, 0, 0)), _borderWidth(0) {
-  
+
   QDomNode n = e.firstChild();
   while (!n.isNull()) {
     QDomElement el = n.toElement(); 
     if (!el.isNull()) {
       if (metaObject()->findProperty(el.tagName().latin1(), true) > -1) {
-        setProperty(el.tagName().latin1(), QVariant(el.text()));  
-      }  
+        setProperty(el.tagName().latin1(), QVariant(el.text()));
+      }
     }
-    n = n.nextSibling();      
+    n = n.nextSibling();
   }
-  
+
   // these always have these values
   _type = "Box";
+  _editTitle = i18n("Edit Box");
   _standardActions |= Delete | Edit;
   _layoutActions |= Delete | Raise | Lower | RaiseToTop | LowerToBottom | Rename | MoveTo | Copy | CopyTo;
   _fallThroughTransparency = false;
@@ -75,7 +77,7 @@ KstViewBox::KstViewBox(const KstViewBox& box)
   _borderColor = box._borderColor;
   _borderWidth = box._borderWidth;
   _transparentFill = box._transparentFill;
-  
+
   // these always have these values
   _type = "Box";
 }
@@ -95,6 +97,13 @@ KstViewObject* KstViewBox::copyObjectQuietly(KstViewObject& parent, const QStrin
 }
 
 
+KstViewObject* KstViewBox::copyObjectQuietly() const {
+  KstViewBox *viewBox = new KstViewBox(*this);
+
+  return viewBox;
+}
+
+
 void KstViewBox::paintSelf(KstPainter& p, const QRegion& bounds) {
   p.save();
   if (p.type() != KstPainter::P_PRINT && p.type() != KstPainter::P_EXPORT) {
@@ -115,7 +124,7 @@ void KstViewBox::paintSelf(KstPainter& p, const QRegion& bounds) {
   if (bw > _geom.height()) {
     bw = _geom.height() / 2;
   }
-  
+
   QPen pen(borderColor(), bw);
   pen.setJoinStyle(_cornerStyle);
   if (bw == 0) {
@@ -123,7 +132,7 @@ void KstViewBox::paintSelf(KstPainter& p, const QRegion& bounds) {
   }
   p.setPen(pen);
   if (_transparentFill) {
-    p.setBrush(Qt::NoBrush);  
+    p.setBrush(Qt::NoBrush);
   } else {
     p.setBrush(_foregroundColor);
   }
@@ -147,13 +156,15 @@ void KstViewBox::save(QTextStream& ts, const QString& indent) {
 
 void KstViewBox::setXRound(int rnd) {
   int crnd;
+
   if (rnd < 0) {
-    crnd = 0;  
+    crnd = 0;
   } else if (rnd > 99) {
-    crnd = 99;  
+    crnd = 99;
   } else {
-    crnd = rnd;  
+    crnd = rnd;
   }
+
   if (_xRound != crnd) {
     setDirty();
     _xRound = crnd;
@@ -163,13 +174,15 @@ void KstViewBox::setXRound(int rnd) {
 
 void KstViewBox::setYRound(int rnd) {
   int crnd;
+
   if (rnd < 0) {
-    crnd = 0;  
+    crnd = 0;
   } else if (rnd > 99) {
-    crnd = 99;  
+    crnd = 99;
   } else {
-    crnd = rnd;  
+    crnd = rnd;
   }
+
   if (_yRound != crnd) {
     setDirty();
     _yRound = crnd;
@@ -307,4 +320,4 @@ KST_REGISTER_VIEW_OBJECT(Box, create_KstViewBox, handler_KstViewBox)
 
 
 #include "kstviewbox.moc"
-// vim: ts=2 sw=2 et
+
