@@ -20,14 +20,15 @@
 #include "kstviewellipse.h"
 #include "kstviewobjectfactory.h"
 
-#include <klocale.h>
-
 #include <qmetaobject.h>
 #include <qpainter.h>
 #include <qvariant.h>
 
+#include <klocale.h>
+
 KstViewEllipse::KstViewEllipse()
 : KstViewObject("Ellipse"), _borderWidth(1) {
+  _editTitle = i18n("Edit Ellipse");
   setTransparent(true);
   _transparentFill = false;
   _standardActions |= Delete | Edit;
@@ -43,13 +44,14 @@ KstViewEllipse::KstViewEllipse(const QDomElement& e)
     if (!el.isNull()) {
       if (metaObject()->findProperty(el.tagName().latin1(), true) > -1) {
         setProperty(el.tagName().latin1(), QVariant(el.text()));  
-      }  
+      }
     }
-    n = n.nextSibling();      
+    n = n.nextSibling();
   }
-  
+
   // always have these values
   _type = "Ellipse";
+  _editTitle = i18n("Edit Ellipse");
   setTransparent(true);
   _standardActions |= Delete | Edit;
   _layoutActions |= Delete | Raise | Lower | RaiseToTop | LowerToBottom | Rename | MoveTo | Copy | CopyTo;
@@ -61,7 +63,7 @@ KstViewEllipse::KstViewEllipse(const KstViewEllipse& ellipse)
   _transparentFill = ellipse._transparentFill;
   _borderWidth = ellipse._borderWidth;
   _borderColor = ellipse._borderColor;
-  
+
   // these always have these values
   _type = "Ellipse";
   _standardActions |= Delete | Edit;
@@ -77,7 +79,14 @@ KstViewObject* KstViewEllipse::copyObjectQuietly(KstViewObject& parent, const QS
 
   KstViewEllipse* viewEllipse = new KstViewEllipse(*this);
   parent.appendChild(viewEllipse, true);
-  
+
+  return viewEllipse;
+}
+
+
+KstViewObject* KstViewEllipse::copyObjectQuietly() const {
+  KstViewEllipse* viewEllipse = new KstViewEllipse(*this);
+
   return viewEllipse;
 }
 
@@ -95,20 +104,32 @@ void KstViewEllipse::paintSelf(KstPainter& p, const QRegion& bounds) {
     }
   }
 
-  const int bw(_borderWidth * p.lineWidthAdjustmentFactor());
+  const QRect g(geometry());
+  int bw(_borderWidth * p.lineWidthAdjustmentFactor());
+
+  if (bw > g.width()/2) {
+    bw = g.width()/2;
+  }
+  if (bw > g.height()/2) {
+    bw = g.height()/2;
+  }
   QPen pen(bw > 0 ? _borderColor : _foregroundColor, bw);
   p.setPen(pen);
   if (_transparentFill) {
-    p.setBrush(Qt::NoBrush);  
+    p.setBrush(Qt::NoBrush);
   } else {
     p.setBrush(_foregroundColor);
   }
-  const QRect g(geometry());
   p.drawEllipse(g.x() + bw/2, g.y() + bw/2, g.width() - bw, g.height() - bw);
   p.restore();
 }
 
 
+QRegion KstViewEllipse::region() {
+  return QRegion(geometry(), QRegion::Ellipse);
+}
+
+
 void KstViewEllipse::save(QTextStream& ts, const QString& indent) {
   ts << indent << "<" << type() << ">" << endl;
   KstViewObject::save(ts, indent + "  ");
@@ -143,7 +164,7 @@ int KstViewEllipse::borderWidth() const {
 
 
 void KstViewEllipse::setForegroundColor(const QColor& color) {
-  KstViewObject::setForegroundColor(color);  
+  KstViewObject::setForegroundColor(color);
 }
 
 
@@ -178,10 +199,10 @@ QMap<QString, QVariant> KstViewEllipse::widgetHints(const QString& propertyName)
 
 signed int KstViewEllipse::directionFor(const QPoint& pos) {
   signed int direction = KstViewObject::directionFor(pos);
+
   if (direction != 0) {
-    // not moving, so in any resize direction, we want it centred
-    direction |= CENTEREDRESIZE;  
-  }  
+    direction |= CENTEREDRESIZE;
+  }
   return direction;
 }
 
@@ -192,7 +213,7 @@ void KstViewEllipse::drawShadow(KstPainter& p, const QPoint& pos) {
   p.drawEllipse(rect);  
 }
 
-    
+
 void KstViewEllipse::setTransparentFill(bool yes) {
   if (_transparentFill != yes) {
     _transparentFill = yes;
@@ -221,4 +242,4 @@ KST_REGISTER_VIEW_OBJECT(Ellipse, create_KstViewEllipse, handler_KstViewEllipse)
 
 
 #include "kstviewellipse.moc"
-// vim: ts=2 sw=2 et
+
