@@ -72,6 +72,7 @@ KstViewLabel::KstViewLabel(const QString& txt, KstLJustifyType justify, float ro
   _parsed = 0L;
   _labelMargin = 0;
   _isResizable = false;
+  _editTitle = i18n("Edit Label");
   reparse();
   computeTextSize(_parsed);
 }
@@ -83,6 +84,7 @@ KstViewLabel::KstViewLabel(const QDomElement& e)
   _fallThroughTransparency = false;
   _container = false;
   _type = "Label";
+  _editTitle = i18n("Edit Label");
   _dataPrecision = 8;
   _interpret = true;
   _replace = true;
@@ -96,7 +98,7 @@ KstViewLabel::KstViewLabel(const QDomElement& e)
   _parsed = 0L;
   _isResizable = false;
   reparse();
-  
+
   // read the properties
   QDomNode n = e.firstChild();
   while (!n.isNull()) {
@@ -104,7 +106,7 @@ KstViewLabel::KstViewLabel(const QDomElement& e)
     if (!el.isNull()) {
       if (metaObject()->findProperty(el.tagName().latin1(), true) > -1) {
         setProperty(el.tagName().latin1(), QVariant(el.text()));  
-      }  
+      }
     }
     n = n.nextSibling();
   }
@@ -113,7 +115,8 @@ KstViewLabel::KstViewLabel(const QDomElement& e)
 
 KstViewLabel::KstViewLabel(const KstViewLabel& label)
 : KstBorderedViewObject(label) {
-  
+  _editTitle = i18n("Edit Label");
+
   _dataPrecision = label._dataPrecision;
   _interpret = label._interpret;
   _replace = label._replace;
@@ -128,7 +131,7 @@ KstViewLabel::KstViewLabel(const KstViewLabel& label)
 
   _parsed = 0L;
   reparse();
-  
+
   // these always have these values
   _type = "Label";
 }
@@ -150,6 +153,13 @@ KstViewObject* KstViewLabel::copyObjectQuietly(KstViewObject& parent, const QStr
 }
 
 
+KstViewObject* KstViewLabel::copyObjectQuietly() const {
+  KstViewLabel* viewLabel = new KstViewLabel(*this);
+
+  return viewLabel;
+}
+
+
 void KstViewLabel::setupConnections() {
   for (KstScalarMap::iterator i = _scalarsUsed.begin(); i != _scalarsUsed.end(); ++i) {
     disconnect(i.data(), SIGNAL(tagChanged()), this, SLOT(reparse()));
@@ -404,65 +414,69 @@ void KstViewLabel::paintSelf(KstPainter& p, const QRegion& bounds) {
   p.save();
   if (p.type() == KstPainter::P_PRINT || p.type() == KstPainter::P_EXPORT) {
     int absFontSizeOld = _absFontSize;
-    
+
     QRect cr(contentsRectForPainter(p));
     cr.setSize(sizeForText(_parent->geometry()));
-    setContentsRectForPainter(p, cr);    
+    setContentsRectForPainter(p, cr);
     KstBorderedViewObject::paintSelf(p, bounds);
-    
+
     p.translate(cr.left(), cr.top());
     if (!_transparent) {
       p.fillRect(0, 0, cr.width(), cr.height(), backgroundColor());
     }
     drawToPainter(_parsed, p);
-    
+
     _absFontSize = absFontSizeOld;
   } else {
     if (p.makingMask()) {
+      KstBorderedViewObject::paintSelf(p, bounds);
       p.setRasterOp(Qt::SetROP);
+      const QRect cr(contentsRect());
+      // slow but preserves antialiasing...
+      QBitmap bm = _backBuffer.buffer().createHeuristicMask(false);
+      bm.setMask(bm);
+      p.drawPixmap(cr.left(), cr.top(), bm, 0, 0, cr.width(), cr.height());
     } else {
       const QRegion clip(clipRegion());
-      KstBorderedViewObject::paintSelf(p, bounds - _myClipMask);
+      KstBorderedViewObject::paintSelf(p, bounds);
       p.setClipRegion(bounds & clip);
+      _backBuffer.paintInto(p, contentsRect());
     }
-
-    _backBuffer.paintInto(p, contentsRect());
   }
   p.restore();
 }
 
 
-void KstViewLabel::invalidateClipRegion() {
-  KstBorderedViewObject::invalidateClipRegion();
-  _myClipMask = QRegion();
-}
-
-
 QRegion KstViewLabel::clipRegion() {
-  if (!_transparent) {
-    return KstBorderedViewObject::clipRegion();
-  }
+  if (_clipMask.isNull()) {
+    if (_transparent) {
+      const QRect cr(contentsRect());
+      // slow but preserves antialiasing...
+      QBitmap bm = _backBuffer.buffer().createHeuristicMask(false);
 
-  if (_clipMask.isNull() && _myClipMask.isNull()) {
-    const QRect cr(contentsRect());
-    QBitmap bm = _backBuffer.buffer().createHeuristicMask(false); // slow but preserves antialiasing...
-    _myClipMask = QRegion(bm);
-    _myClipMask.translate(cr.topLeft().x(), cr.topLeft().y());
+      _clipMask = QRegion(bm);
+      _clipMask.translate(cr.topLeft().x(), cr.topLeft().y());
 
-    QBitmap bm1(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
-    if (!bm1.isNull()) {
-      KstPainter p;
-      p.setMakingMask(true);
-      p.begin(&bm1);
-      p.setViewXForm(true);
-      KstBorderedViewObject::paintSelf(p, QRegion());
-      p.flush();
-      p.end();
-      _clipMask = QRegion(bm1);
+      QBitmap bm1(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
+      if (!bm1.isNull()) {
+        KstPainter p;
+
+        p.setMakingMask(true);
+        p.begin(&bm1);
+        p.setViewXForm(true);
+        KstBorderedViewObject::paintSelf(p, QRegion());
+        paint(p, QRegion());
+        p.flush();
+        p.end();
+
+        _clipMask |= QRegion(bm1);
+      }
+    } else {
+      _clipMask = KstBorderedViewObject::clipRegion();
     }
   }
 
-  return _clipMask | _myClipMask;
+  return _clipMask;
 }
 
 
@@ -472,7 +486,7 @@ void KstViewLabel::setFontSize(int size) {
     if (_absFontSize < KstSettings::globalSettings()->plotFontMinSize) {
       _absFontSize = KstSettings::globalSettings()->plotFontMinSize;
     }
-    
+
     _fontSize = size;
     setDirty();
   }
@@ -493,7 +507,7 @@ void KstViewLabel::adjustSizeForText(const QRect& w) {
 
 QSize KstViewLabel::sizeForText(const QRect& w) {
   double x_s, y_s;
-  
+
   x_s = y_s = _fontSize + (double)KstSettings::globalSettings()->plotFontSize;
 
   int x_pix = w.width();
@@ -511,7 +525,7 @@ QSize KstViewLabel::sizeForText(const QRect& w) {
   if (_absFontSize < KstSettings::globalSettings()->plotFontMinSize) {
     _absFontSize = KstSettings::globalSettings()->plotFontMinSize;
   }
- 
+
   if (!_parsed) {
     reparse();
   }
@@ -519,7 +533,7 @@ QSize KstViewLabel::sizeForText(const QRect& w) {
   if (_parsed) {
     computeTextSize(_parsed);
   }
- 
+
   QSize sz(kMax(1, _textWidth), kMax(1, _textHeight));
 
   if (int(_rotation) != 0 && int(_rotation) != 180) {
@@ -550,7 +564,7 @@ QSize KstViewLabel::sizeForText(const QRect& w) {
       sz = r.intersect(_parent->geometry()).size();
     }
   }
-    
+
   return sz;
 }
 
@@ -590,8 +604,7 @@ void KstViewLabel::writeBinary(QDataStream& str) {
 void KstViewLabel::readBinary(QDataStream& str) {
   KstBorderedViewObject::readBinary(str);
   bool b;
-  str >> _rotation >> _txt >> _fontName
-      >> b;
+  str >> _rotation >> _txt >> _fontName >> b;
   _replace = b;
   str >> b;
   _interpret = b;
@@ -603,92 +616,94 @@ void KstViewLabel::readBinary(QDataStream& str) {
 }
 
 
-double KstViewLabel::rotation() const { 
+double KstViewLabel::rotation() const {
   return _rotation; 
 }
 
+
 bool KstViewLabel::fillConfigWidget(QWidget *w, bool isNew) const {
   ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
   if (!widget) {
     return false;
   }
-  
-  if (isNew) { // probably a new label: set widget to defaults
-    widget->_precision->setValue(8);
-    widget->_rotation->setValue(0);
-    widget->_fontSize->setValue(0);
-    widget->_horizontal->setCurrentItem(0);
-    widget->_fontColor->setColor(KstSettings::globalSettings()->foregroundColor);
-    widget->_font->setCurrentFont(KstApp::inst()->defaultFont());
-    widget->_margin->setValue(5);
 
-    widget->_boxColors->setForeground(KstSettings::globalSettings()->foregroundColor);
-    widget->_boxColors->setBackground(KstSettings::globalSettings()->backgroundColor);
-
-    if (size().width() * size().height() < 25) { // assume a click, and default to just text
-      widget->_transparent->setChecked(true);
-      widget->_border->setValue(0);
-    } else { // someone drew a box, so assume that is what they wanted
-      widget->_transparent->setChecked(false);
-      widget->_border->setValue(2);
-    }
-
-  } else {
-    // No, this is broken.  It kills latex.
-#if 0
-    // replace \n & \t with tabs and newlines for the text edit box
-    QString tmpstr = text();
-    tmpstr.replace(QString("\\n"), "\n");
-    tmpstr.replace(QString("\\t"), "\t");
-    widget->_text->setText(tmpstr);
-#endif
+  if (!isNew) {
     widget->_text->setText(text());
-
-    widget->_precision->setValue(int(dataPrecision()));
-    widget->_rotation->setValue(double(rotation()));
-    widget->_fontSize->setValue(int(fontSize()));
-    widget->_horizontal->setCurrentItem(horizJustifyWrap());
-    widget->_fontColor->setColor(foregroundColor());
-    widget->_font->setCurrentFont(fontName());
-
-    widget->_transparent->setChecked(transparent());
-    widget->_border->setValue(borderWidth());
-    widget->_boxColors->setForeground(borderColor());
-    widget->_boxColors->setBackground(backgroundColor());
-    widget->_margin->setValue(_labelMargin);
   }
+
+  widget->_precision->setValue(int(dataPrecision()));
+  widget->_rotation->setValue(double(rotation()));
+  widget->_fontSize->setValue(int(fontSize()));
+  widget->_horizontal->setCurrentItem(horizJustifyWrap());
+  widget->_fontColor->setColor(foregroundColor());
+  widget->_font->setCurrentFont(fontName());
+
+  widget->_transparent->setChecked(transparent());
+  widget->_border->setValue(borderWidth());
+  widget->_boxColors->setForeground(borderColor());
+  widget->_boxColors->setBackground(backgroundColor());
+  widget->_margin->setValue(labelMargin());
+
   widget->_text->setFocus();
+
   return true;
 }
 
 
-bool KstViewLabel::readConfigWidget(QWidget *w) {
+bool KstViewLabel::readConfigWidget(QWidget *w, bool editMultipleMode) {
   ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
   if (!widget) {
     return false;
   }
 
-  _txt = widget->_text->text();
-  // No, this is broken.  It kills latex.
-#if 0
-  // Replace tabs and newlines in text edit box with \n and \t 
-  _txt.replace(QString("\n"), "\\n");
-  _txt.replace(QString("\t"), "\\t");
-#endif
+  if (!editMultipleMode || widget->_text->text().compare(QString(" ")) != 0) {
+    _txt = widget->_text->text();
+  }
 
-  setDataPrecision(widget->_precision->value());
-  setRotation(widget->_rotation->value());
-  setFontSize(widget->_fontSize->value());
-  setHorizJustifyWrap(widget->_horizontal->currentItem());
-  setForegroundColor(widget->_fontColor->color());
-  setFontName(widget->_font->currentFont());
+  if (!editMultipleMode || widget->_precision->value() != widget->_precision->minValue()) {
+    setDataPrecision(widget->_precision->value());
+  }
+
+  if (!editMultipleMode || widget->_rotation->value() != widget->_rotation->minValue()) {
+    setRotation(widget->_rotation->value());
+  }
+
+  if (!editMultipleMode || widget->_fontSize->value() != widget->_fontSize->minValue()) {
+    setFontSize(widget->_fontSize->value());
+  }
+
+  if (!editMultipleMode || widget->_horizontal->currentText().compare(QString(" ")) != 0) {
+    setHorizJustifyWrap(widget->_horizontal->currentItem());
+  }
+
+  if (!editMultipleMode || widget->_fontColor->color() != QColor()) {
+    setForegroundColor(widget->_fontColor->color());
+  }
+
+  if (!editMultipleMode || widget->_font->currentText().compare(QString(" ")) != 0) {
+    setFontName(widget->_font->currentFont());
+  }
+
+  if (!editMultipleMode || widget->_transparent->state() != QButton::NoChange) {
+    setTransparent(widget->_transparent->isChecked());
+  }
+
+  if (!editMultipleMode || widget->_border->value() != widget->_border->minValue()) {
+    setBorderWidth(widget->_border->value());
+  }
+
+  if (!editMultipleMode || widget->_changedFgColor) {
+    setBorderColor(widget->_boxColors->foreground());
+  }
+
+  if (!editMultipleMode || widget->_changedBgColor) {
+    setBackgroundColor(widget->_boxColors->background());
+  }
+
+  if (!editMultipleMode || widget->_margin->value() != widget->_margin->minValue()) {
+    setLabelMargin(widget->_margin->value());
+  }
 
-  setTransparent(widget->_transparent->isChecked());
-  setBorderWidth(widget->_border->value());
-  setBorderColor(widget->_boxColors->foreground());
-  setBackgroundColor(widget->_boxColors->background());
-  setLabelMargin(widget->_margin->value());
- 
   reparse(); // calls setDirty()
   return true;
 }
@@ -699,7 +714,7 @@ void KstViewLabel::connectConfigWidget(QWidget *parent, QWidget *w) const {
   if (!widget) {
     return;
   }
-  
+
   connect(widget->_text, SIGNAL(textChanged()), parent, SLOT(modified()));
   connect(widget->_font, SIGNAL(activated(int)), parent, SLOT(modified()));
   connect(widget->_fontSize, SIGNAL(valueChanged(int)), parent, SLOT(modified()));
@@ -710,10 +725,12 @@ void KstViewLabel::connectConfigWidget(QWidget *parent, QWidget *w) const {
   connect(widget->_precision->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), parent, SLOT(modified()));
   connect(widget->_rotation, SIGNAL(valueChanged(int)), parent, SLOT(modified()));
   connect(widget->_rotation, SIGNAL(valueChanged(double)), parent, SLOT(modified()));
-  connect(widget->_rotation->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), parent, SLOT(modified()));  
+  connect(widget->_rotation->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), parent, SLOT(modified()));
   connect(widget->_transparent, SIGNAL(pressed()), parent, SLOT(modified()));
   connect(widget->_boxColors, SIGNAL(fgChanged(const QColor&)), parent, SLOT(modified()));
   connect(widget->_boxColors, SIGNAL(bgChanged(const QColor&)), parent, SLOT(modified()));
+  connect(widget->_boxColors, SIGNAL(fgChanged(const QColor&)), widget, SLOT(changedFgColor()));
+  connect(widget->_boxColors, SIGNAL(bgChanged(const QColor&)), widget, SLOT(changedBgColor()));
   connect(widget->_margin, SIGNAL(valueChanged(int)), parent, SLOT(modified()));
   connect(widget->_margin->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), parent, SLOT(modified()));
   connect(widget->_border, SIGNAL(valueChanged(int)), parent, SLOT(modified()));
@@ -721,17 +738,64 @@ void KstViewLabel::connectConfigWidget(QWidget *parent, QWidget *w) const {
 }
 
 
+void KstViewLabel::populateEditMultiple(QWidget *w) {
+  ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
+  if (!widget) {
+    return;
+  }
+
+  widget->_text->setText(QString(" "));
+
+  widget->_font->insertItem(QString(" "));
+  widget->_font->setCurrentItem(widget->_font->count()-1);
+
+  widget->_fontSize->setMinValue(widget->_fontSize->minValue() - 1);
+  widget->_fontSize->setSpecialValueText(QString(" "));
+  widget->_fontSize->setValue(widget->_fontSize->minValue());
+
+  widget->_horizontal->insertItem(QString(" "));
+  widget->_horizontal->setCurrentItem(widget->_horizontal->count()-1);
+
+  widget->_fontColor->setColor(QColor());
+
+  widget->_transparent->setTristate();
+  widget->_transparent->setNoChange();
+
+  widget->_boxColors->setForeground(QColor());
+  widget->_boxColors->setBackground(QColor());
+
+  widget->_precision->setMinValue(widget->_precision->minValue() - 1);
+  widget->_precision->setSpecialValueText(QString(" "));
+  widget->_precision->setValue(widget->_precision->minValue());
+
+  widget->_rotation->setMinValue(widget->_rotation->minValue() - 1);
+  widget->_rotation->setSpecialValueText(QString(" "));
+  widget->_rotation->setValue(widget->_rotation->minValue());
+
+  widget->_margin->setMinValue(widget->_margin->minValue() - 1);
+  widget->_margin->setSpecialValueText(QString(" "));
+  widget->_margin->setValue(widget->_margin->minValue());
+
+  widget->_border->setMinValue(widget->_border->minValue() - 1);
+  widget->_border->setSpecialValueText(QString(" "));
+  widget->_border->setValue(widget->_border->minValue());
+
+  widget->_changedFgColor = false;
+  widget->_changedBgColor = false;
+}
+
+
 void KstViewLabel::setDataPrecision(int prec) {
   int n;
-  
+
   if (prec < 0) {
-    n = 0;  
+    n = 0;
   } else if (prec > 16) {
-    n = 16;  
+    n = 16;
   } else {
-    n = prec;  
+    n = prec;
   }
-  
+
   if (n != _dataPrecision) {
     setDirty();
     _dataPrecision = n;
@@ -774,11 +838,11 @@ int KstViewLabel::horizJustifyWrap() const {
 
 void KstViewLabel::setHorizJustifyWrap(int justify) {
   Q_UINT8 justifySet;
-  
+
   switch (justify) {
     case 0:
       justifySet = KST_JUSTIFY_H_LEFT;
-      break;  
+      break;
     case 1:
       justifySet = KST_JUSTIFY_H_RIGHT;
       break;
@@ -791,8 +855,10 @@ void KstViewLabel::setHorizJustifyWrap(int justify) {
   setJustification(SET_KST_JUSTIFY(justifySet, KST_JUSTIFY_V(justification())));
 }
 
+
 void KstViewLabel::setLabelMargin(int margin) {
   int mm = kMax(0, margin);
+
   if (mm != _labelMargin) {
     _labelMargin = mm;
     setDirty();
@@ -805,8 +871,8 @@ int KstViewLabel::labelMargin() const {
 }
 
 
-QWidget *KstViewLabel::configWidget() {
-  return new ViewLabelWidget;
+QWidget *KstViewLabel::configWidget(QWidget *parent) {
+  return new ViewLabelWidget(parent, "custom");
 }
 
 
@@ -841,6 +907,7 @@ void KstViewLabel::DataCache::update() {
           }
         }
         break;
+
       case DataRef::DRString:
         {
           KST::stringList.lock().readLock();
@@ -855,6 +922,7 @@ void KstViewLabel::DataCache::update() {
           }
         }
         break;
+
       case DataRef::DRExpression:
         {
           bool ok = false;
@@ -864,6 +932,7 @@ void KstViewLabel::DataCache::update() {
           }
         }
         break;
+
       case DataRef::DRVector:
         {
           bool ok = false;
@@ -884,6 +953,7 @@ void KstViewLabel::DataCache::update() {
           }
         }
         break;
+
       case DataRef::DataRef::DRFit:
         {
           KST::dataObjectList.lock().readLock();
@@ -896,7 +966,7 @@ void KstViewLabel::DataCache::update() {
               if (fit->label((int)((*i).indexValue)) != (*i).index) {
                 valid = false;
               }
-              fit->unlock();     
+              fit->unlock();
             }
           }
         }
@@ -906,4 +976,4 @@ void KstViewLabel::DataCache::update() {
 }
 
 #include "kstviewlabel.moc"
-// vim: ts=2 sw=2 et
+
