@@ -23,6 +23,7 @@
 #include "kst2dplot.h"
 #include "kstdatacollection.h"
 #include "kstdataobjectcollection.h"
+#include "kstlegenddefaults.h"
 #include "kst.h"
 #include "kstsettings.h"
 #include "ksttimers.h"
@@ -57,23 +58,28 @@
 
 KstViewLegend::KstViewLegend()
 : KstBorderedViewObject("Legend") {
+  _editTitle = i18n("Edit Legend");
+  _fontName = KST::legendDefaults.font();
+  _vertical = KST::legendDefaults.vertical();
+  _legendMargin = KST::legendDefaults.margin();
+  _trackContents = KST::legendDefaults.trackContents();
+
+  _fontSize = -1;
+  setFontSize(KST::legendDefaults.fontSize());
+  setForegroundColor(KST::legendDefaults.fontColor());
+  setBorderColor(KST::legendDefaults.foregroundColor());
+  setBackgroundColor(KST::legendDefaults.backgroundColor());
+  setBorderWidth(KST::legendDefaults.border());
+  setTransparent(KST::legendDefaults.transparent());
+
   _fallThroughTransparency = false;
   _container = false;
   _rotation = 0;
-  _vertical = true;
-  _fontName = KstApp::inst()->defaultFont();
   _isResizable = false;
-  setForegroundColor(KstSettings::globalSettings()->foregroundColor);
-  setBorderColor(KstSettings::globalSettings()->foregroundColor);
-  setBackgroundColor(KstSettings::globalSettings()->backgroundColor);
-  setBorderWidth(2);
-  _legendMargin = 5;
-  _fontSize = -1;  
-  setFontSize(0);
   _layoutActions &= ~(MoveTo | Copy | CopyTo);
   _standardActions |= Delete | Edit;
   _parsedTitle = 0L;
-  _trackContents = true;
+
   reparseTitle();
   computeTextSize();
   setDirty(false);
@@ -82,23 +88,29 @@ KstViewLegend::KstViewLegend()
 
 KstViewLegend::KstViewLegend(const QDomElement& e)
 : KstBorderedViewObject(e) {
+  _editTitle = i18n("Edit Legend");
+  _fontName = KST::legendDefaults.font();
+  _vertical = KST::legendDefaults.vertical();
+  _legendMargin = KST::legendDefaults.margin();
+  _trackContents = KST::legendDefaults.trackContents();
+
+  _fontSize = -1;
+  setFontSize(KST::legendDefaults.fontSize());
+  setForegroundColor(KST::legendDefaults.fontColor());
+  setBorderColor(KST::legendDefaults.foregroundColor());
+  setBackgroundColor(KST::legendDefaults.backgroundColor());
+  setBorderWidth(KST::legendDefaults.border());
+  setTransparent(KST::legendDefaults.transparent());
 
-  // some defaults and invariants
   _fallThroughTransparency = false;
-  _container = false;
   _type = "Legend";
   _rotation = 0.0;
-  _fontName = KstApp::inst()->defaultFont();
-  _vertical = true;
+  _container = false;
   _isResizable = false;
-  _fontSize = -1;
-  setFontSize(0);
   _layoutActions &= ~(MoveTo | Copy | CopyTo);
   _standardActions |= Delete | Edit;
-  _legendMargin = 5;
   _parsedTitle = 0L;
-  _trackContents = true;
-  
+
   QStringList ctaglist;
 
   // read the properties
@@ -138,10 +150,11 @@ KstViewLegend::KstViewLegend(const QDomElement& e)
 
 KstViewLegend::KstViewLegend(const KstViewLegend& legend)
 : KstBorderedViewObject(legend) {
+  _editTitle = i18n("Edit Legend");
   _type = "Legend";
   _layoutActions &= ~(MoveTo | Copy | CopyTo);
   _standardActions |= Delete | Edit;
-  
+
   _fallThroughTransparency = legend._fallThroughTransparency;
   _container = legend._container;
   _rotation = legend._rotation;
@@ -155,7 +168,7 @@ KstViewLegend::KstViewLegend(const KstViewLegend& legend)
   _parsedTitle = 0L;
   _trackContents = legend._trackContents;
   _curves = QDeepCopy<KstBaseCurveList>(legend._curves);
-  
+
   reparseTitle();
   computeTextSize();
 }
@@ -169,7 +182,7 @@ KstViewLegend::~KstViewLegend() {
 
 KstViewObject* KstViewLegend::copyObjectQuietly(KstViewObject &parent, const QString& name) const { 
   Q_UNUSED(name)
-  
+
   KstViewLegend* viewLegend = new KstViewLegend(*this);
   parent.appendChild(viewLegend, true);
 
@@ -177,6 +190,13 @@ KstViewObject* KstViewLegend::copyObjectQuietly(KstViewObject &parent, const QSt
 }
 
 
+KstViewObject* KstViewLegend::copyObjectQuietly() const { 
+  KstViewLegend* viewLegend = new KstViewLegend(*this);
+
+  return viewLegend;
+}
+
+
 void KstViewLegend::resize(const QSize& size) {
   KstBorderedViewObject::resize(size);
   if (!_parsedTitle) {
@@ -219,13 +239,15 @@ void KstViewLegend::save(QTextStream &ts, const QString& indent) {
 
 
 void KstViewLegend::drawToBuffer() {
+  KstPainter p;
+  QPen pen;
+
   setDirty(false);
 
   _backBuffer.buffer().resize(contentsRect().size());
   _backBuffer.buffer().fill(backgroundColor());
-  KstPainter p;
+
   p.begin(&_backBuffer.buffer());
-  QPen pen;
   pen.setColor(foregroundColor());
   p.setPen(pen);
   drawToPainter(p);
@@ -374,66 +396,68 @@ void KstViewLegend::updateSelf() {
 
 
 void KstViewLegend::paintSelf(KstPainter& p, const QRegion& bounds) {
+  p.save();
   if (p.type() == KstPainter::P_PRINT || p.type() == KstPainter::P_EXPORT) {
-    p.save();
     QRect cr(contentsRectForPainter(p));
     cr.setSize(sizeForText(_parent->geometry()));
-    setContentsRectForPainter(p, cr);    
+    setContentsRectForPainter(p, cr);
     KstBorderedViewObject::paintSelf(p, bounds);
-    
+
     p.translate(cr.left(), cr.top());
     if (!_transparent) {
       p.fillRect(0, 0, cr.width(), cr.height(), _backgroundColor);
     }
     drawToPainter(p);
-    
-    p.restore();
   } else {
-    const QRect cr(contentsRect());
     if (p.makingMask()) {
+      KstBorderedViewObject::paintSelf(p, bounds);
       p.setRasterOp(Qt::SetROP);
+      const QRect cr(contentsRect());
+      // slow but preserves antialiasing...
+      QBitmap bm = _backBuffer.buffer().createHeuristicMask(false);
+      bm.setMask(bm);
+      p.drawPixmap(cr.left(), cr.top(), bm, 0, 0, cr.width(), cr.height());
     } else {
       const QRegion clip(clipRegion());
-      KstBorderedViewObject::paintSelf(p, bounds - _myClipMask);
+      KstBorderedViewObject::paintSelf(p, bounds);
       p.setClipRegion(bounds & clip);
+      _backBuffer.paintInto(p, contentsRect());
     }
-
-    _backBuffer.paintInto(p, cr);
   }
-}
-
-
-void KstViewLegend::invalidateClipRegion() {
-  KstBorderedViewObject::invalidateClipRegion();
-  _myClipMask = QRegion();
+  p.restore();
 }
 
 
 QRegion KstViewLegend::clipRegion() {
-  if (!_transparent) {
-    return KstBorderedViewObject::clipRegion();
-  }
+  if (_clipMask.isNull()) {
+    if (_transparent) {
+      const QRect cr(contentsRect());
+      // slow but preserves antialiasing...
+      QBitmap bm = _backBuffer.buffer().createHeuristicMask(false);
 
-  if (_clipMask.isNull() && _myClipMask.isNull()) {
-    const QRect cr(contentsRect());
-    QBitmap bm = _backBuffer.buffer().createHeuristicMask(false); // slow but preserves antialiasing...
-    _myClipMask = QRegion(bm);
-    _myClipMask.translate(cr.topLeft().x(), cr.topLeft().y());
+      _clipMask = QRegion(bm);
+      _clipMask.translate(cr.topLeft().x(), cr.topLeft().y());
 
-    QBitmap bm1(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
-    if (!bm1.isNull()) {
-      KstPainter p;
-      p.setMakingMask(true);
-      p.begin(&bm1);
-      p.setViewXForm(true);
-      KstBorderedViewObject::paintSelf(p, QRegion());
-      p.flush();
-      p.end();
-      _clipMask = QRegion(bm1);
+      QBitmap bm1(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
+      if (!bm1.isNull()) {
+        KstPainter p;
+
+        p.setMakingMask(true);
+        p.begin(&bm1);
+        p.setViewXForm(true);
+        KstBorderedViewObject::paintSelf(p, QRegion());
+        paint(p, QRegion());
+        p.flush();
+        p.end();
+
+        _clipMask |= QRegion(bm1);
+      }
+    } else {
+      _clipMask = KstBorderedViewObject::clipRegion();
     }
   }
 
-  return _clipMask | _myClipMask;
+  return _clipMask;
 }
 
 
@@ -535,11 +559,13 @@ KstViewObjectFactoryMethod KstViewLegend::factory() const {
 
 /* FIXME: not written for legends yet. */
 void KstViewLegend::writeBinary(QDataStream& str) {
+  Q_UNUSED(str)
 }
 
 
 /* FIXME: not written for legends yet. */
 void KstViewLegend::readBinary(QDataStream& str) {
+  Q_UNUSED(str)
 }
 
 
@@ -593,7 +619,6 @@ void KstViewLegend::reparseTitle() {
 }
 
 
-/** fill the custom widget with current properties */
 bool KstViewLegend::fillConfigWidget(QWidget *w, bool isNew) const {
   ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
   if (!widget) {
@@ -601,30 +626,30 @@ bool KstViewLegend::fillConfigWidget(QWidget *w, bool isNew) const {
   }
 
   KstBaseCurveList allCurves = kstObjectSubList<KstDataObject, KstBaseCurve>(KST::dataObjectList);
-  
+
   if (isNew) {
-    widget->_fontSize->setValue(0);
-    widget->_fontColor->setColor(KstSettings::globalSettings()->foregroundColor);
-    widget->_font->setCurrentFont(KstApp::inst()->defaultFont());
-    widget->_margin->setValue(5);
-    widget->_boxColors->setForeground(KstSettings::globalSettings()->foregroundColor);
-    widget->_boxColors->setBackground(KstSettings::globalSettings()->backgroundColor);
-    widget->_vertical->setChecked(true);
-    widget->_transparent->setChecked(false);
-    widget->_border->setValue(2);
+    widget->_fontSize->setValue(KST::legendDefaults.fontSize());
+    widget->_fontColor->setColor(KST::legendDefaults.fontColor());
+    widget->_font->setCurrentFont(KST::legendDefaults.font());
+    widget->_boxColors->setForeground(KST::legendDefaults.foregroundColor());
+    widget->_boxColors->setBackground(KST::legendDefaults.backgroundColor());
+    widget->_vertical->setChecked(KST::legendDefaults.vertical());
+    widget->_transparent->setChecked(KST::legendDefaults.transparent());
+    widget->_margin->setValue(KST::legendDefaults.margin());
+    widget->_border->setValue(KST::legendDefaults.border());
+    widget->TrackContents->setChecked(KST::legendDefaults.trackContents());
+
     widget->_title->setText("");
-    widget->TrackContents->setChecked(true);
- 
+
     for (KstBaseCurveList::ConstIterator it = allCurves.begin(); it != allCurves.end(); ++it) {
       (*it)->readLock();
       widget->AvailableCurveList->insertItem((*it)->tagName());
       (*it)->unlock();
     }
-
   } else { // fill legend properties into widget
     widget->TrackContents->setChecked(trackContents());
     widget->_title->setText(title());
-    widget->_fontSize->setValue(int(fontSize()));
+    widget->_fontSize->setValue(fontSize());
     widget->_fontColor->setColor(foregroundColor());
     widget->_font->setCurrentFont(fontName());
     widget->_transparent->setChecked(transparent());
@@ -650,49 +675,76 @@ bool KstViewLegend::fillConfigWidget(QWidget *w, bool isNew) const {
 }
 
 
-/** apply properties in the custom config widget to this */
-bool KstViewLegend::readConfigWidget(QWidget *w) {
-  KstViewLegendList legends;
-  KstViewLegendPtr legendExtra;
-
+bool KstViewLegend::readConfigWidget(QWidget *w, bool editMultipleMode) {
   ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
   if (!widget) {
     return false;
   }
 
-  if (widget->_thisLegend->isChecked()) {
-    legends += this;
-  } else if (widget->_thisWindow->isChecked()) {
-    legends = topLevelParent()->findChildrenType<KstViewLegend>(true);
-  } else {
-    legends = globalLegendList();
-  }
-
-  // apply the curve list, but only to this legend!
-  KstBaseCurveList allCurves = kstObjectSubList<KstDataObject, KstBaseCurve>(KST::dataObjectList);
-  _curves.clear();
-  for (unsigned i = 0; i < widget->DisplayedCurveList->count(); i++) {
-    KstBaseCurveList::Iterator it = allCurves.findTag(widget->DisplayedCurveList->text(i));
-    if (it != allCurves.end()) {
-      _curves.append(*it);
+  if (!editMultipleMode) {
+    // apply the curve list, but only to this legend!
+    KstBaseCurveList allCurves = kstObjectSubList<KstDataObject, KstBaseCurve>(KST::dataObjectList);
+    _curves.clear();
+    for (unsigned i = 0; i < widget->DisplayedCurveList->count(); i++) {
+      KstBaseCurveList::Iterator it = allCurves.findTag(widget->DisplayedCurveList->text(i));
+      if (it != allCurves.end()) {
+        _curves.append(*it);
+      }
     }
   }
 
-  for (uint i = 0; i < legends.size(); i++) {
-    legendExtra = legends[i];
+  if (!editMultipleMode || widget->_fontSize->value() != widget->_fontSize->minValue()) {
+    setFontSize(widget->_fontSize->value());
+    KST::legendDefaults.setFontSize(widget->_fontSize->value());
+  }
 
-    legendExtra->setFontSize(widget->_fontSize->value());
-    legendExtra->setForegroundColor(widget->_fontColor->color());
-    legendExtra->setFontName(widget->_font->currentFont());
-    legendExtra->setTitle(widget->_title->text());
+  if (!editMultipleMode || widget->_fontColor->color() != QColor()) {
+    setForegroundColor(widget->_fontColor->color());
+    KST::legendDefaults.setFontColor(widget->_fontColor->color());
+  }
 
-    legendExtra->setTransparent(widget->_transparent->isChecked());
-    legendExtra->setBorderWidth(widget->_border->value());
-    legendExtra->setBorderColor(widget->_boxColors->foreground());
-    legendExtra->setBackgroundColor(widget->_boxColors->background());
-    legendExtra->setLegendMargin(widget->_margin->value());
-    legendExtra->setVertical(widget->_vertical->isChecked());
-    legendExtra->setTrackContents(widget->TrackContents->isChecked());
+  if (!editMultipleMode || widget->_font->currentText().compare(QString(" ")) != 0) {
+    setFontName(widget->_font->currentFont());
+    KST::legendDefaults.setFont(widget->_font->currentFont());
+  }
+
+  if (!editMultipleMode || widget->_title->text().compare(QString(" ")) != 0) {
+    setTitle(widget->_title->text());
+  }
+
+  if (!editMultipleMode || widget->_transparent->state() != QButton::NoChange) {
+    setTransparent(widget->_transparent->isChecked());
+    KST::legendDefaults.setTransparent(widget->_transparent->isChecked());
+  }
+
+  if (!editMultipleMode || widget->_border->value() != widget->_border->minValue()) {
+    setBorderWidth(widget->_border->value());
+    KST::legendDefaults.setBorder(widget->_border->value());
+  }
+
+  if (!editMultipleMode || widget->_changedFgColor) {
+    setBorderColor(widget->_boxColors->foreground());
+    KST::legendDefaults.setForegroundColor(widget->_boxColors->foreground());
+  }
+
+  if (!editMultipleMode || widget->_changedBgColor) {
+    setBackgroundColor(widget->_boxColors->background());
+    KST::legendDefaults.setBackgroundColor(widget->_boxColors->background());
+  }
+
+  if (!editMultipleMode || widget->_margin->value() != widget->_margin->minValue()) {
+    setLegendMargin(widget->_margin->value());
+    KST::legendDefaults.setMargin(widget->_margin->value());
+  }
+
+  if (!editMultipleMode || widget->_vertical->state() != QButton::NoChange) {
+    setVertical(widget->_vertical->isChecked());
+    KST::legendDefaults.setVertical(widget->_vertical->isChecked());
+  }
+
+  if (!editMultipleMode || widget->TrackContents->state() != QButton::NoChange) {
+    setTrackContents(widget->TrackContents->isChecked());
+    KST::legendDefaults.setTrackContents(widget->TrackContents->isChecked());
   }
 
   setDirty();
@@ -719,17 +771,68 @@ void KstViewLegend::connectConfigWidget(QWidget *parent, QWidget *w) const {
   connect(widget->_transparent, SIGNAL(pressed()), parent, SLOT(modified()));
   connect(widget->_boxColors, SIGNAL(fgChanged(const QColor&)), parent, SLOT(modified()));
   connect(widget->_boxColors, SIGNAL(bgChanged(const QColor&)), parent, SLOT(modified()));
+  connect(widget->_boxColors, SIGNAL(fgChanged(const QColor&)), widget, SLOT(changedFgColor()));
+  connect(widget->_boxColors, SIGNAL(bgChanged(const QColor&)), widget, SLOT(changedBgColor()));
   connect(widget->_margin, SIGNAL(valueChanged(int)), parent, SLOT(modified()));
   connect(widget->_margin->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), parent, SLOT(modified()));
   connect(widget->_border, SIGNAL(valueChanged(int)), parent, SLOT(modified()));
   connect(widget->_border->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), parent, SLOT(modified()));
-  connect(widget->_thisLegend, SIGNAL(stateChanged(int)), parent, SLOT(modified()));
-
 }
 
 
-QWidget *KstViewLegend::configWidget() {
-  return new ViewLegendWidget;
+QWidget *KstViewLegend::configWidget(QWidget *parent) {
+  return new ViewLegendWidget(parent, "custom");
+}
+
+
+void KstViewLegend::populateEditMultiple(QWidget *w) {
+  ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
+  if (!widget) {
+    return;
+  }
+
+  widget->AvailableCurveList->setEnabled(false);
+  widget->DisplayedCurveList->setEnabled(false);
+  widget->_remove->setEnabled(false);
+  widget->_add->setEnabled(false);
+  widget->_up->setEnabled(false);
+  widget->_down->setEnabled(false);
+
+  widget->_title->setText(QString(" "));
+
+  widget->_font->insertItem(QString(" "));
+  widget->_font->setCurrentItem(widget->_font->count()-1);
+
+  widget->_fontSize->setMinValue(widget->_fontSize->minValue() - 1);
+  widget->_fontSize->setSpecialValueText(QString(" "));
+  widget->_fontSize->setValue(widget->_fontSize->minValue());
+
+  widget->_vertical->setTristate();
+  widget->_vertical->setNoChange();
+
+  widget->_fontColor->setColor(QColor());
+
+  widget->_transparent->setTristate();
+  widget->_transparent->setNoChange();
+
+  widget->_boxColors->setForeground(QColor());
+  widget->_boxColors->setBackground(QColor());
+
+  widget->_margin->setMinValue(widget->_margin->minValue() - 1);
+  widget->_margin->setSpecialValueText(QString(" "));
+  widget->_margin->setValue(widget->_margin->minValue());
+
+  widget->_border->setMinValue(widget->_border->minValue() - 1);
+  widget->_border->setSpecialValueText(QString(" "));
+  widget->_border->setValue(widget->_border->minValue());
+
+  widget->_changedFgColor = false;
+  widget->_changedBgColor = false;
+}
+
+
+bool KstViewLegend::supportsDefaults() {
+  return false;
 }
 
 
