@@ -301,18 +301,20 @@ void KstViewObject::saveAttributes(QTextStream& ts, const QString& indent) {
     ts << indent << "<" << metaObject()->property(i, true)->name() << ">";
     ts << property(metaObject()->property(i, true)->name()).toString().latin1();
     ts << "</" << metaObject()->property(i, true)->name() << ">" << endl;
-  }  
+  }
 }
 
 
 void KstViewObject::paint(KstPainter& p, const QRegion& bounds) {
   bool maximized = false;
+
   if (p.type() == KstPainter::P_EXPORT || p.type() == KstPainter::P_PRINT) {
     // handle the case where we have maximized plots
     for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
       if ((*i)->_maximized) {
         (*i)->paint(p, bounds);
         maximized = true;
+
         break;
       }
     }
@@ -323,6 +325,7 @@ void KstViewObject::paint(KstPainter& p, const QRegion& bounds) {
         (*i)->paint(p, bounds);
       }
     }
+
     return;
   }
 
@@ -346,12 +349,14 @@ void KstViewObject::paint(KstPainter& p, const QRegion& bounds) {
     if ((*i)->_maximized) {
       (*i)->paint(p, bounds);
       maximized = true;
+
       break;
     }
   }
 
   if (!maximized) {
     QRegion clipRegion;
+
     if (nullBounds) {
       clipRegion = geometry();
     } else {
@@ -362,6 +367,7 @@ void KstViewObject::paint(KstPainter& p, const QRegion& bounds) {
       KstViewObjectList::Iterator begin = _children.begin();
       for (KstViewObjectList::Iterator i = _children.fromLast();; --i) {
         const QRegion thisObjectGeometry((*i)->geometry());
+
         if (nullBounds || !clipRegion.intersect(thisObjectGeometry).isEmpty()) {
 #ifdef BENCHMARK
           QTime t;
@@ -374,12 +380,13 @@ void KstViewObject::paint(KstPainter& p, const QRegion& bounds) {
           kstdDebug() << "   -> object " << (*i)->tagName() << " took " << x << "ms" << endl;
 #endif
         }
+
         if (i == begin) {
           break;
         }
       }
     }
-    // Paint ourself
+
     paintSelf(p, clipRegion - p.uiMask());
   }
 
@@ -464,8 +471,8 @@ void KstViewObject::drawFocusRect(KstPainter& p) {
 
 
 void KstViewObject::drawSelectRect(KstPainter& p) {
-  p.setBrush(QBrush(Qt::green));
-  p.setPen(QPen(Qt::black, 0));
+  p.setBrush(QBrush(foregroundColor()));
+  p.setPen(QPen(backgroundColor(), 0));
   drawFocusRect(p);
 }
 
@@ -508,7 +515,7 @@ void KstViewObject::prependChild(KstViewObjectPtr obj, bool keepAspect) {
 
 bool KstViewObject::removeChild(KstViewObjectPtr obj, bool recursive) {
   bool rc = _children.remove(obj) > 0;
-  
+
   if (recursive) {
     for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
       rc = (*i)->removeChild(obj, true) && rc;
@@ -516,7 +523,7 @@ bool KstViewObject::removeChild(KstViewObjectPtr obj, bool recursive) {
   }
 
   obj->_parent = 0L;
-  
+
   return rc;
 }
 
@@ -544,6 +551,22 @@ void KstViewObject::insertChildAfter(const KstViewObjectPtr after, KstViewObject
 }
 
 
+KstViewObjectList KstViewObject::findChildrenType( const QString& type, bool recursive) {
+  KstViewObjectList rc;
+  for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
+    if ((*i)->type().compare(type) == 0) {
+      rc.append(*i);
+    }
+
+    if (recursive) {
+      rc += (*i)->findChildrenType(type, recursive);
+    }
+  }
+
+  return rc;
+}
+
+
 void KstViewObject::clearChildren() {
   for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
     (*i)->_parent = 0L;
@@ -697,176 +720,218 @@ void KstViewObject::setOnGrid(bool on_grid) {
 
 
 void KstViewObject::cleanup(int cols) {
+  //
+  // if cols <= 0, the optimal value is chosen automatically
+  //
+
   KstViewObjectList childrenCopy;
-  double ave_w = 0.0;
-  bool dirty = false;
+  double widthTotal = 0.0;
+  double widthAverage = 0.0;
 
   for (KstViewObjectList::ConstIterator i = _children.begin(); i != _children.end(); ++i) {
     if ((*i)->followsFlow()) {
       childrenCopy.append(*i);
-      ave_w += (*i)->aspectRatio().w;
+      widthTotal += (*i)->aspectRatio().w;
     }
   }
 
   int cnt = childrenCopy.count();
 
-  if (cnt < 1) {
-    return;
-  }
-  ave_w /= double(cnt);
+  if (cnt > 0) {
+    widthAverage = widthTotal / double(cnt);
 
-  // FIXME: don't allow regrid to a number of columns that will result in
-  //        >= height() plots in a column
-  if (cols <= 0) {
-    if (ave_w > 0 ) { // guess current column alignment based on the average width of existing plots
-      cols = int(1.0 / ave_w + 0.5); 
-      if (cols > cnt) {
+    // FIXME: don't allow regrid to a number of columns that will result in
+    //        >= height() plots in a column
+    if (cols <= 0) {
+      if (widthAverage > 0.0) { // guess current column alignment based on the average width of existing plots
+        cols = int(1.0 / widthAverage + 0.5);
+        if (cols > cnt) {
+          cols = int(sqrt(cnt));
+        }
+      } else {
         cols = int(sqrt(cnt));
       }
+    }
+
+    if (!_onGrid) {
+      _onGrid = true;
+      _columns = kMax(1, cols);
+      cleanupRandomLayout(_columns, childrenCopy);
     } else {
-      cols = int(sqrt(cnt));
+      if (cols > 0) {
+        _columns = cols;
+      } else if (cols <= 0) {
+        _columns = kMax(1, int(sqrt(cnt)));
+      }
+      cleanupGridLayout(_columns, childrenCopy);
     }
   }
+}
 
-  if (!_onGrid) {
-    _onGrid = true;
-    _columns = kMax(1, cols);
-  } else {
-    if (cols > 0) {
-      _columns = cols;
-      assert(_columns > 0);
-    } else if (cols <= 0){
-      _columns = kMax(1, int(sqrt(cnt)));
+
+void KstViewObject::cleanupGridLayout(int cols, KstViewObjectList &childrenCopy) {
+  int cnt = childrenCopy.count();
+
+  if (cols > 0 && cnt > 0) {
+    int row;
+    int col;
+    int rows = ( cnt + cols - 1 ) / cols;
+    QSize sz(_geom.width() / cols, _geom.height() / rows);
+
+    for (col=0; col<cols; ++col) {
+      for (row=0; row<rows; ++row) {
+        if (col + (row * cols) < cnt) {
+          KstViewObjectPtr plot = childrenCopy[col + (row * cols)];
+          QPoint pt(sz.width() * col, sz.height() * row);
+
+          plot->move(pt);
+          plot->resize(sz);
+          plot->setDirty();
+        } else {
+          break;
+        }
+      }
     }
   }
+}
 
-  int rows = ( cnt + _columns - 1 ) / _columns;
 
-  QMemArray<int> plotLoc(rows * _columns); // what plot lives at each grid location
-  QMemArray<int> unAssigned(cnt); // what plots haven't got a home yet?
-  int n_unassigned = 0;
-  int r, c, CR;
-  for (int i = 0; i < rows * _columns; ++i) {
-    plotLoc[i] = -1;
-  }
+void KstViewObject::cleanupRandomLayout(int cols, KstViewObjectList &childrenCopy) {
+  int cnt = childrenCopy.count();
 
-  // put the plots on a grid.  Each plot goes to the closest grid location
-  // unless there is another plot which is closer, in which case the 
-  // plot gets dumped into an un-assigned list for placement into a
-  // random un-filled grid space.
-  // the location is defined relative to the left-middle.
-  // QUESTION: should we use the middle-middle instead?
-  // NOTE: the choice of grid location assumes a regular grid, which is
-  // broken when supressed axis/labels are taken into account.  This
-  // could have an effect if the plots are grown by >50%.
-  for (int i = 0; i < cnt; ++i) {
-    r = int((childrenCopy[i]->aspectRatio().y+childrenCopy[i]->aspectRatio().h/2)*rows); // use center
-    c = int(childrenCopy[i]->aspectRatio().x*_columns+0.5);
+  if (cols > 0 && cnt > 0) {
+    int rows = ( cnt + cols - 1 ) / cols;
 
-    if (c >= _columns) {
-      c = _columns-1;
+    QMemArray<int> plotLoc(rows * cols); // what plot lives at each grid location
+    QMemArray<int> unAssigned(cnt); // what plots haven't got a home yet?
+    int n_unassigned = 0;
+    int row, col, CR;
+    for (int i = 0; i < rows * cols; ++i) {
+      plotLoc[i] = -1;
     }
-    if (r >= rows) {
-      r = rows-1;
-    }
-    CR = c + r*_columns;
-    if (childrenCopy[i]->dirty()) { // newly added plots get no priority
-      dirty = true;
-      unAssigned[n_unassigned] = i;
-      n_unassigned++;
-    } else if (plotLoc[CR] < 0) {
-      plotLoc[CR] = i;
-    } else { // another plot is already at this grid point
 
-      double d1, d2;
-      // put the further of the two in the unassigned list
-      // use Manhatten distance.
-      d1 = fabs(double(r) - childrenCopy[i]->aspectRatio().y*rows) + 
-          fabs(double(c) - childrenCopy[i]->aspectRatio().x*_columns);
-      d2 = fabs(double(r) - childrenCopy[plotLoc[CR]]->aspectRatio().y*rows) + 
-          fabs(double(c) - childrenCopy[plotLoc[CR]]->aspectRatio().x*_columns);      
-      if (d1 >= d2) { 
+    // put the plots on a grid.  Each plot goes to the closest grid location
+    // unless there is another plot which is closer, in which case the 
+    // plot gets dumped into an un-assigned list for placement into a
+    // random un-filled grid space.
+    // the location is defined relative to the left-middle.
+    // QUESTION: should we use the middle-middle instead?
+    // NOTE: the choice of grid location assumes a regular grid, which is
+    // broken when supressed axis/labels are taken into account.  This
+    // could have an effect if the plots are grown by >50%.
+    for (int i = 0; i < cnt; ++i) {
+      row = int( ( childrenCopy[i]->aspectRatio().y + childrenCopy[i]->aspectRatio().h / 2 ) * rows );
+      col = int( childrenCopy[i]->aspectRatio().x * cols + 0.5 );
+
+      if (col >= cols) {
+        col = cols-1;
+      }
+      if (row >= rows) {
+        row = rows-1;
+      }
+      CR = col + row * cols;
+      if (childrenCopy[i]->dirty()) { // newly added plots get no priority
         unAssigned[n_unassigned] = i;
-      } else {
-        unAssigned[n_unassigned] = plotLoc[CR];
+        n_unassigned++;
+      } else if (plotLoc[CR] < 0) {
         plotLoc[CR] = i;
-      }
-      n_unassigned++;
-    }
-  }
-  // now dump the unassigned plots in random holes.
-  // Question: should we dump them in the closest holes?
-  CR = 0;
-  for (int i = 0; i < n_unassigned; ++i) {
-    for (; plotLoc[CR] != -1; ++CR) { }
-    plotLoc[CR] = unAssigned[i];
-  }
-
-  QMemArray<double> HR(rows);
-  double sum_HR = 0.0;
-  KstViewObject *ob;
-  double hr;
-
-  for (r=0; r<rows; r++) {
-    HR[r] = 10.0;
-    for (c=0; c<_columns; c++) {
-      CR = c + r*_columns;
-      if (plotLoc[CR] > -1) {
-        hr = childrenCopy[plotLoc[CR]]->verticalSizeFactor();
-        if (hr < HR[r]) {
-          HR[r] = hr;
+      } else { // another plot is already at this grid point
+        //
+        // put the further of the two in the unassigned list using Manhattan distance.
+        //
+        double d1 = fabs(double(row) - childrenCopy[i]->aspectRatio().y*rows) + 
+            fabs(double(col) - childrenCopy[i]->aspectRatio().x*cols);
+        double d2 = fabs(double(row) - childrenCopy[plotLoc[CR]]->aspectRatio().y*rows) + 
+            fabs(double(col) - childrenCopy[plotLoc[CR]]->aspectRatio().x*cols);
+        if (d1 >= d2) {
+          unAssigned[n_unassigned] = i;
+        } else {
+          unAssigned[n_unassigned] = plotLoc[CR];
+          plotLoc[CR] = i;
         }
+        n_unassigned++;
       }
     }
-    if (HR[r] > 9.0) {
-      HR[r] = 1.0;
+
+    //
+    // now dump the unassigned plots in random holes.
+    // Question: should we dump them in the closest holes?
+    //
+    CR = 0;
+    for (int i = 0; i < n_unassigned; ++i) {
+      for (; plotLoc[CR] != -1; ++CR) { }
+      plotLoc[CR] = unAssigned[i];
     }
-    sum_HR += HR[r];
-  }
 
-  // now actually move/resize the plots
-  int w = _geom.width() / _columns;
-  int h = 0;
-  int y = 0;
-  for (r=0; r<rows; r++) {
-    y += h;
-    h = int(double(_geom.height()) * HR[r]/sum_HR);
-    for (c=0; c<_columns; c++) {
-      CR = c + r*_columns;
-      if (plotLoc[CR] >= 0) {
-        QSize sz(w, h);
-        r = CR / _columns;
-        c = CR % _columns;
-        QPoint pt(w*c, y);
+    QMemArray<double> HR(rows);
+    double sum_HR = 0.0;
+    KstViewObject *ob;
+    double hr;
 
-        // if necessary adjust the last column so that we don't spill over
-        if (c == _columns-1) {
-          // only adjust the final width if necessary as we would rather have a gap
-          // at the right edge of the window than a column of plots that is significantly 
-          // wider than all the others
-          if (w*_columns > _geom.width()) {
-            sz.setWidth(_geom.width() - w*c);
+    for (row=0; row<rows; row++) {
+      HR[row] = 10.0;
+      for (col=0; col<cols; col++) {
+        CR = col + row*cols;
+        if (plotLoc[CR] > -1) {
+          hr = childrenCopy[plotLoc[CR]]->verticalSizeFactor();
+          if (hr < HR[row]) {
+            HR[row] = hr;
           }
         }
+      }
+      if (HR[row] > 9.0) {
+        HR[row] = 1.0;
+      }
+      sum_HR += HR[row];
+    }
 
-        // if necessary adjust the last row so that we don't spill over
-        if (r == rows - 1) {
-          // only adjust the final height if necessary as we would rather have a gap
-          // at the bottom edge of the window than a row of plots that is significantly 
-          // taller than all the others
-          if (y + h > _geom.height()) {
-            sz.setHeight(_geom.height() - y);
+    //
+    // now actually move/resize the plots
+    //
+    int w = _geom.width() / cols;
+    int h = 0;
+    int y = 0;
+
+    for (row=0; row<rows; row++) {
+      y += h;
+      h = int(double(_geom.height()) * HR[row]/sum_HR);
+      for (col=0; col<cols; col++) {
+        CR = col + row*cols;
+        if (plotLoc[CR] >= 0) {
+          QSize sz(w, h);
+          row = CR / cols;
+          col = CR % cols;
+          QPoint pt(w*col, y);
+
+          // if necessary adjust the last column so that we don't spill over
+          if (col == cols-1) {
+            // only adjust the final width if necessary as we would rather have a gap
+            // at the right edge of the window than a column of plots that is significantly 
+            // wider than all the others
+            if (w*cols > _geom.width()) {
+              sz.setWidth(_geom.width() - w*col);
+            }
           }
-        }
 
-        ob = childrenCopy[plotLoc[CR]];
-        ob->move(pt);
-        ob->resize(sz);
-        // FIXME: This is here to trigger axis alignment updates when cleanup
-        // happens.  Remove this once we can trigger an axis alignment update
-        // without setting dirty since this is a performance penalty.
-        // (It even causes non-plots to redraw)
-        ob->setDirty();
+          // if necessary adjust the last row so that we don't spill over
+          if (row == rows - 1) {
+            // only adjust the final height if necessary as we would rather have a gap
+            // at the bottom edge of the window than a row of plots that is significantly 
+            // taller than all the others
+            if (y + h > _geom.height()) {
+              sz.setHeight(_geom.height() - y);
+            }
+          }
+
+          ob = childrenCopy[plotLoc[CR]];
+          ob->move(pt);
+          ob->resize(sz);
+          // FIXME: This is here to trigger axis alignment updates when cleanup
+          // happens.  Remove this once we can trigger an axis alignment update
+          // without setting dirty since this is a performance penalty.
+          // (It even causes non-plots to redraw)
+          ob->setDirty();
+        }
       }
     }
   }
@@ -989,7 +1054,7 @@ KstViewObjectPtr KstViewObject::findChild(const QPoint& pos, bool borderForTrans
         if ((*i)->transparent()) {
           if (!(*i)->fallThroughTransparency() && (*i)->geometry().contains(pos)) {
             obj = *i;
-          } else if ((*i)->clipRegion().contains(pos)) {
+          } else if ((*i)->region().contains(pos)) {
             obj = *i;
           } else if (borderForTransparent && (*i)->geometry().contains(pos)) {
             const QRect g((*i)->geometry());
@@ -1117,7 +1182,7 @@ bool KstViewObject::popupMenu(KPopupMenu *menu, const QPoint& pos, KstViewObject
 //     menu->insertItem(i18n("&Copy"), this, SLOT(copyObject()));
 //     rc = true;
 //   }
-  
+
   if (_layoutActions & Rename) {
     menu->insertItem(i18n("Re&name..."), this, SLOT(rename()));
     rc = true;
@@ -1152,7 +1217,7 @@ bool KstViewObject::layoutPopupMenu(KPopupMenu *menu, const QPoint& pos, KstView
   bool rc = false;
   int id;
   int index;
-  
+
   _moveToMap.clear();
 
   if (!tagName().isEmpty()) {
@@ -1163,7 +1228,7 @@ bool KstViewObject::layoutPopupMenu(KPopupMenu *menu, const QPoint& pos, KstView
     menu->insertItem(i18n("&Edit..."), this, SLOT(edit()));
     rc = true;
   }
-  
+
   if (_layoutActions & Delete) {
     menu->insertItem(i18n("&Delete"), this, SLOT(deleteObject()));
     rc = true;
@@ -1286,17 +1351,26 @@ void KstViewObject::edit() {
 void KstViewObject::deleteObject() {
   KstApp::inst()->document()->setModified();
   KstViewObjectPtr vop(this);
+
   if (_topObjectForMenu) {
     KstTopLevelViewPtr tlv = kst_cast<KstTopLevelView>(KstViewObjectPtr(_topObjectForMenu));
+
     if (tlv && vop == tlv->pressTarget()) {
       tlv->clearPressTarget();
     }
+
+    if (this->_parent) {
+      this->_parent->invalidateClipRegion();
+    }
+
     _topObjectForMenu->removeChild(this, true);
     _topObjectForMenu = 0L;
   }
+
   while (!_children.isEmpty()) {
     removeChild(_children.first());
   }
+
   vop = 0L; // basically "delete this;"
   QTimer::singleShot(0, KstApp::inst(), SLOT(updateDialogs()));
 }
@@ -1314,6 +1388,11 @@ KstViewObject* KstViewObject::copyObjectQuietly(KstViewObject &parent, const QSt
 }
 
 
+KstViewObject* KstViewObject::copyObjectQuietly() const {
+  return 0L;
+}
+
+
 void KstViewObject::raiseToTop() {
   if (_parent) {
     KstViewObjectPtr t = this;
@@ -1384,7 +1463,6 @@ void KstViewObject::lower() {
 }
 
 
-// FIXME: delete
 void KstViewObject::moveTo(int id) {
   QString windowName = _moveToMap[id];
 
@@ -1406,7 +1484,6 @@ void KstViewObject::moveTo(int id) {
 }
 
 
-// FIXME: delete
 void KstViewObject::copyTo(int id) {
   QString windowName = _copyToMap[id];
 
@@ -1582,7 +1659,7 @@ void KstViewObject::rename() {
       done = ok = true;
     }
   }
-  
+
   if (ok) {
     setTagName(KstObjectTag(newName, KstObjectTag::globalTagContext)); // FIXME: handle tag context
   } else {
@@ -1751,7 +1828,7 @@ bool KstViewObject::paste(QMimeSource* source, KstViewObjectList* list) {
       for (size_t i=0; i<plotList.size(); i++) {
         KstViewObjectPtr copy = w->view()->findChild(plotList[i]);
         KstViewObject *created;
-        
+
         if (copy) {
           QString plotName;
           bool duplicate = true;
@@ -1824,6 +1901,10 @@ const QString& KstViewObject::type() const {
 }
 
 
+const QString& KstViewObject::editTitle() const {
+  return _editTitle;
+}
+
 void KstViewObject::setMinimumSize(const QSize& sz) {
   _minimumSize = sz.expandedTo(QSize(1, 1)); // 1,1 is the absolute minimum
 }
@@ -1853,8 +1934,9 @@ QRegion KstViewObject::clipRegion() {
       QBitmap bm(_geom.bottomRight().x(), _geom.bottomRight().y(), true);
       if (!bm.isNull()) {
         KstPainter p;
-        p.setMakingMask(true);
+
         p.begin(&bm);
+        p.setMakingMask(true);
         p.setViewXForm(true);
         paint(p, QRegion());
         p.flush();
@@ -1872,6 +1954,11 @@ QRegion KstViewObject::clipRegion() {
 }
 
 
+QRegion KstViewObject::region() {
+  return clipRegion();
+}
+
+
 void KstViewObject::setFollowsFlow(bool follow) {
   _followsFlow = follow;
 }
@@ -1942,7 +2029,7 @@ signed int KstViewObject::directionFor(const QPoint& pos) {
       direction |= RIGHT;
     }
   }
-  
+
   return direction;
 }
 
@@ -1964,6 +2051,7 @@ bool KstViewObject::showDialog(KstTopLevelViewPtr invoker, bool isNew) {
 void KstViewObject::drawShadow(KstPainter& p, const QPoint& pos) {
   // default is a rectangle
   QRect rect(geometry());
+
   rect.moveTopLeft(pos);
   p.drawRect(rect);
 }
@@ -1988,7 +2076,9 @@ bool KstViewObject::objectDirty() const {
 }
 
 
-QWidget *KstViewObject::configWidget() {
+QWidget *KstViewObject::configWidget(QWidget *parent) {
+  Q_UNUSED(parent)
+
   return 0L;
 }
 
@@ -1996,12 +2086,15 @@ QWidget *KstViewObject::configWidget() {
 bool KstViewObject::fillConfigWidget(QWidget *w, bool isNew) const {
   Q_UNUSED(w)
   Q_UNUSED(isNew)
+
   return false;
 }
 
 
-bool KstViewObject::readConfigWidget(QWidget *w) {
+bool KstViewObject::readConfigWidget(QWidget *w, bool editMultipleMode) {
   Q_UNUSED(w)
+  Q_UNUSED(editMultipleMode)
+
   return false;
 }
 
@@ -2012,6 +2105,14 @@ void KstViewObject::connectConfigWidget(QWidget *parent, QWidget *w) const {
 }
 
 
+void KstViewObject::populateEditMultiple(QWidget *w) {
+  Q_UNUSED(w)
+}
+
+bool KstViewObject::supportsDefaults() {
+  return true;
+}
+
 KstGfxMouseHandler *KstViewObject::createHandler() {
   return 0L;
 }
@@ -2039,6 +2140,11 @@ bool KstViewObject::isResizable() const {
 
 void KstViewObject::invalidateClipRegion() {
   _clipMask = QRegion();
+  if (_parent) {
+    if (_parent->transparent()) {
+      _parent->invalidateClipRegion();
+    }
+  }
 }
 
 
@@ -2056,9 +2162,9 @@ KstViewObjectPtr KstViewObject::topLevelParent() const {
   while (p->_parent) {
     p = p->_parent;
   }
-    
+
   return static_cast<KstViewObject*>(p);
 }
 
 #include "kstviewobject.moc"
-// vim: ts=2 sw=2 et
+
