@@ -73,8 +73,8 @@ class KST_EXPORT KstViewObject : public KstObject {
 
     virtual void invalidateClipRegion();
     virtual QRegion clipRegion();
+    virtual QRegion region();
 
-    // If cols <= 0, optimal is chosen automatically
     virtual void cleanup(int cols = -1);
     virtual int columns() const;
     virtual void setColumns(int cols);
@@ -82,7 +82,6 @@ class KST_EXPORT KstViewObject : public KstObject {
     virtual void setOnGrid(bool on_grid);
 
     virtual void resize(const QSize& size);
-    // FIXME: this stuff has got to go.
     virtual void resizeForPrint(const QSize& size);
     virtual void revertForPrint();
     virtual void resizeFromAspect(double x, double y, double w, double h);
@@ -101,7 +100,7 @@ class KST_EXPORT KstViewObject : public KstObject {
     // in the row.  1.0 means that the dataRect = geometry.  >1 means dataRect < geometry.
     virtual double verticalSizeFactor();
     virtual double horizontalSizeFactor();
-    
+
     virtual void move(const QPoint& to);
 
     // Draw a focus highlight
@@ -124,8 +123,8 @@ class KST_EXPORT KstViewObject : public KstObject {
     bool objectDirty() const; // true if this object or a child is dirty
     bool fallThroughTransparency() const;
     bool isResizable() const;
-    
-    virtual QWidget *configWidget();
+
+    virtual QWidget *configWidget(QWidget *parent);
 
     // can't be const due to KstViewObjectPtr?
     // I don't like this method at all, but for now it makes things work.  Maybe
@@ -136,6 +135,7 @@ class KST_EXPORT KstViewObject : public KstObject {
     KstViewObjectPtr findChild(const QString& name, bool recursive = true);
     bool contains(const KstViewObjectPtr child) const;
     template<class T> KstObjectList<KstSharedPtr<T> > findChildrenType(bool recursive = false);
+    KstViewObjectList findChildrenType( const QString& type, bool recursive = false);
 
     // Finds a container that can hold this rect.  Only searches objects that
     // are containers.
@@ -157,7 +157,7 @@ class KST_EXPORT KstViewObject : public KstObject {
 
     virtual void updateSelection(const QRect& region);
     bool isContainer() const;
-    
+
     KstViewObjectPtr parent() const;
     KstViewObjectPtr topLevelParent() const;
 
@@ -204,6 +204,7 @@ class KST_EXPORT KstViewObject : public KstObject {
     virtual void detach(); // remove from its parent
 
     const QString& type() const;
+    const QString& editTitle() const;
 
     virtual bool mouseHandler() const;
     virtual void mouseMoveEvent(QWidget *view, QMouseEvent *e);
@@ -226,7 +227,7 @@ class KST_EXPORT KstViewObject : public KstObject {
 
     void setMinimumSize(const QSize& sz);
     const QSize& minimumSize() const;
-    
+
     // returns the mouse direction for this position on this view object
     enum Direction {NONE = 0, 
                     UP = 1, 
@@ -236,7 +237,7 @@ class KST_EXPORT KstViewObject : public KstObject {
                     CENTEREDRESIZE = 16,
                     ENDPOINT = 32};
     virtual signed int directionFor(const QPoint& pos);
-    
+
     // returns instructions for the edit dialog of this view object
     // given a property name
     // FIXME: Don't use QMap.  We need to preserve order here.
@@ -247,11 +248,13 @@ class KST_EXPORT KstViewObject : public KstObject {
 
     // handle custom widget, if any: is called by KstEditViewObjectDialogI
     virtual bool fillConfigWidget(QWidget *w, bool isNew) const;
-    virtual bool readConfigWidget(QWidget *w);
+    virtual bool readConfigWidget(QWidget *w, bool editMultipleMode);
     virtual void connectConfigWidget(QWidget *parent, QWidget *w) const;
-    
+    virtual void populateEditMultiple(QWidget *w);
+    virtual bool supportsDefaults();
+
     virtual bool paste(QMimeSource* source, KstViewObjectList *list = 0L);
-    
+
     virtual KstGfxMouseHandler *createHandler();
     void setDirty(bool = true);
 
@@ -267,6 +270,7 @@ class KST_EXPORT KstViewObject : public KstObject {
     virtual void zoomToggle();
     virtual void copyObject();
     virtual KstViewObject* copyObjectQuietly(KstViewObject& parent, const QString& name = QString::null) const;
+    virtual KstViewObject* copyObjectQuietly() const;
     virtual bool showDialog(KstTopLevelViewPtr invoker, bool isNew);
 
   protected slots:
@@ -297,11 +301,13 @@ class KST_EXPORT KstViewObject : public KstObject {
     virtual void writeBinary(QDataStream& str);
     virtual void readBinary(QDataStream& str);
     KstObject::UpdateType updateChildren(int counter);
-    
+    void cleanupGridLayout(int cols, KstViewObjectList &childrenCopy);
+    void cleanupRandomLayout(int cols, KstViewObjectList &childrenCopy);
+
     KstViewObjectList _children;
     QRect _geom;
     QRect _geomOld;
-    QColor _backgroundColor, _foregroundColor; // FIXME: use QColorGroup
+    QColor _backgroundColor, _foregroundColor;
     bool _hasFocus : 1;
     bool _focus : 1;
     bool _selected : 1;
@@ -323,6 +329,7 @@ class KST_EXPORT KstViewObject : public KstObject {
     QSize _idealSize; //ideal size for object. useful when _maintainAspect==true
     KstAspectRatio _aspectOldZoomedObject;
     QString _type;
+    QString _editTitle;
     QRegion _clipMask; // The mask of this object
     QMap<int, QString> _moveToMap;
     QMap<int, QString> _copyToMap;
@@ -390,4 +397,4 @@ KstObjectList<KstSharedPtr<T> > KstViewObject::findChildrenType(bool recursive)
 }
 
 #endif
-// vim: ts=2 sw=2 et
+
