@@ -37,6 +37,7 @@
 
 KstViewPicture::KstViewPicture()
 : KstBorderedViewObject("Picture") {
+  _editTitle = i18n("Edit Picture");
   _refresh = 0;
   _timer = 0L;
   setTransparent(true);
@@ -63,6 +64,7 @@ KstViewPicture::KstViewPicture(const QDomElement& e)
 
   // always have these values
   _type = "Picture";
+  _editTitle = i18n("Edit Picture");
   setTransparent(true);
   _standardActions |= Delete | Edit;
 }
@@ -70,10 +72,12 @@ KstViewPicture::KstViewPicture(const QDomElement& e)
 
 KstViewPicture::KstViewPicture(const KstViewPicture& picture)
 : KstBorderedViewObject(picture) {
+  _timer = 0L;
+  _maintainAspect = picture._maintainAspect;
   _refresh = picture._refresh;
   _url = picture._url;
   doRefresh();
-  
+
   // always have these values
   _type = "Picture";
   _standardActions |= Delete | Edit;
@@ -86,42 +90,44 @@ KstViewPicture::~KstViewPicture() {
 
 KstViewObject* KstViewPicture::copyObjectQuietly(KstViewObject& parent, const QString& name) const {
   Q_UNUSED(name)
-  
+
   KstViewPicture* viewPicture = new KstViewPicture(*this);
   parent.appendChild(viewPicture, true);
-  
+
+  return viewPicture;
+}
+
+
+KstViewObject* KstViewPicture::copyObjectQuietly() const {
+  KstViewPicture* viewPicture = new KstViewPicture(*this);
+
   return viewPicture;
 }
 
 
 QRegion KstViewPicture::clipRegion() {
   if (_clipMask.isNull()) {
-    _myClipMask = QRegion();
-    QBitmap bm1(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
-    if (!bm1.isNull()) {
+    QBitmap bm(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
+    if (!bm.isNull()) {
       KstPainter p;
+
       p.setMakingMask(true);
-      p.begin(&bm1);
+      p.begin(&bm);
       p.setViewXForm(true);
       KstBorderedViewObject::paintSelf(p, QRegion());
+      paint(p, QRegion());
       p.flush();
-      p.end();
-      _clipMask = QRegion(bm1);
-    }
-    QBitmap bm2(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
-    if (!bm2.isNull()) {
-      KstPainter p;
-      p.setMakingMask(true);
-      p.begin(&bm2);
-      p.setViewXForm(true);
+      _clipMask = QRegion(bm);
+
+      p.eraseRect(0, 0, _geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1);
       paintSelf(p, QRegion());
       p.flush();
+      _clipMask |= QRegion(bm);
       p.end();
-      _myClipMask = QRegion(bm2);
     }
   }
 
-  return _myClipMask | _clipMask;
+  return _clipMask;
 }
 
 
@@ -129,10 +135,11 @@ void KstViewPicture::paintSelf(KstPainter& p, const QRegion& bounds) {
   p.save();
   if (p.type() != KstPainter::P_PRINT && p.type() != KstPainter::P_EXPORT) {
     if (p.makingMask()) {
+      KstBorderedViewObject::paintSelf(p, bounds);
       p.setRasterOp(Qt::OrROP);
     } else {
       const QRegion clip(clipRegion());
-      KstBorderedViewObject::paintSelf(p, bounds - _myClipMask);
+      KstBorderedViewObject::paintSelf(p, bounds);
       p.setClipRegion(bounds & clip);
     }
   } else {
@@ -147,16 +154,14 @@ void KstViewPicture::paintSelf(KstPainter& p, const QRegion& bounds) {
     p.drawRect(cr);
     p.drawLine(cr.topLeft(), cr.bottomRight());
     p.drawLine(cr.topRight(), cr.bottomLeft());
-  } else {
-    assert(!cr.isNull()); // Null view objects are not allowed.  I want to see
-                          // how this happens so it can be fixed.
-
+  } else if (!cr.isNull()) {
     if (_iCache.isNull() || _iCache.size() != cr.size()) {
       _iCache = _image.copy();
       if (!_iCache.isNull()) {
         _iCache = _iCache.smoothScale(cr.size());
       }
     }
+
     if (!_iCache.isNull()) {
       if (p.makingMask()) {
         // which indicates clipping / BW mode
@@ -167,10 +172,13 @@ void KstViewPicture::paintSelf(KstPainter& p, const QRegion& bounds) {
           p.drawRect(cr);
         }
       } else {
+        _iCache.setAlphaBuffer(false);
         p.drawImage(cr.topLeft(), _iCache);
+        _iCache.setAlphaBuffer(true);
       }
     }
   }
+
   p.restore();
 }
 
@@ -220,7 +228,9 @@ bool KstViewPicture::setImage(const QString& source) {
     setImage(ti);
     _url = source;
 
-    if (_maintainAspect == true) { restoreAspect(); }
+    if (_maintainAspect) { 
+      restoreAspect();
+    }
   } else {
     success = false;
   }
@@ -282,7 +292,7 @@ bool KstViewPicture::transparent() const {
   if (!_iCache.isNull()) {
     return _iCache.hasAlphaBuffer();
   }
-  
+
   return _image.hasAlphaBuffer();
 }
 
@@ -304,6 +314,7 @@ void KstViewPicture::setMaintainAspect(bool maintain) {
 
 void KstViewPicture::restoreSize() {
   QRect cr(contentsRect());
+
   cr.setSize(_image.size());
   setContentsRect(cr);
 }
@@ -313,7 +324,8 @@ void KstViewPicture::restoreAspect() {
   QRect cr(contentsRect());
   QSize size = _image.size(); //start with original size.
 
-  size.scale( cr.size().width(), cr.size().height(), QSize::ScaleMin ); //find largest rect. which will fit inside original and still preserve aspect.
+  // find largest rect. which will fit inside original and still preserve aspect
+  size.scale( cr.size().width(), cr.size().height(), QSize::ScaleMin ); 
 
   cr.setSize(size);
   setContentsRect(cr);
@@ -365,4 +377,4 @@ KST_REGISTER_VIEW_OBJECT(Picture, create_KstViewPicture, handler_KstViewPicture)
 
 
 #include "kstviewpicture.moc"
-// vim: ts=2 sw=2 et
+
