@@ -36,6 +36,9 @@
 extern "C" int yyparse();
 extern "C" void *ParsedEquation;
 extern "C" struct yy_buffer_state *yy_scan_string(const char*);
+extern "C" struct yy_buffer_state *yy_scan_bytes(const char*, int);
+typedef struct yy_buffer_state *YY_BUFFER_STATE;
+extern "C" void yy_delete_buffer(YY_BUFFER_STATE);
 
 using namespace Equation;
 
@@ -46,7 +49,7 @@ QMutex& Equation::mutex() {
 }
 
 
-double Equation::interpret(const char *txt, bool *ok) {
+double Equation::interpret(const char *txt, bool *ok, int len) {
   if (!txt || !*txt) {
     if (ok) {
       *ok = false;
@@ -55,8 +58,14 @@ double Equation::interpret(const char *txt, bool *ok) {
   }
 
   mutex().lock();
-  yy_scan_string(txt);
+  YY_BUFFER_STATE b;
+  if (len > 0) {
+    b = yy_scan_bytes(txt, len);
+  } else {
+    b = yy_scan_string(txt);
+  }
   int rc = yyparse();
+  yy_delete_buffer(b);
   if (rc == 0) {
     Equation::Node *eq = static_cast<Equation::Node*>(ParsedEquation);
     ParsedEquation = 0L;
@@ -98,7 +107,7 @@ bool Node::collectObjects(KstVectorMap&, KstScalarMap&, KstStringMap&) {
 }
 
 
-bool Node::takeVectors(const KstVectorMap&) {
+bool Node::takeVectorsAndScalars(const KstVectorMap&, const KstScalarMap&) {
   return true;
 }
 
@@ -137,9 +146,9 @@ bool BinaryNode::collectObjects(KstVectorMap& v, KstScalarMap& s, KstStringMap&
 }
 
 
-bool BinaryNode::takeVectors(const KstVectorMap& c) {
-  bool rc = _left->takeVectors(c);
-  rc = _right->takeVectors(c) && rc;
+bool BinaryNode::takeVectorsAndScalars(const KstVectorMap& vm, const KstScalarMap& sm) {
+  bool rc = _left->takeVectorsAndScalars(vm, sm);
+  rc = _right->takeVectorsAndScalars(vm, sm) && rc;
   return rc;
 }
 
@@ -162,6 +171,7 @@ Node *& BinaryNode::right() {
 KstObject::UpdateType BinaryNode::update(int counter, Context *ctx) {
   KstObject::UpdateType l = _left->update(counter, ctx);
   KstObject::UpdateType r = _right->update(counter, ctx);
+
   return (l == KstObject::UPDATE || r == KstObject::UPDATE) ? KstObject::UPDATE : KstObject::NO_CHANGE;
 }
 
@@ -608,8 +618,8 @@ bool Function::collectObjects(KstVectorMap& v, KstScalarMap& s, KstStringMap& t)
 }
 
 
-bool Function::takeVectors(const KstVectorMap& c) {
-  return _args->takeVectors(c);
+bool Function::takeVectorsAndScalars(const KstVectorMap& vm, const KstScalarMap& sm) {
+  return _args->takeVectorsAndScalars(vm, sm);
 }
 
 
@@ -663,10 +673,10 @@ bool ArgumentList::collectObjects(KstVectorMap& v, KstScalarMap& s, KstStringMap
 }
 
 
-bool ArgumentList::takeVectors(const KstVectorMap& c) {
+bool ArgumentList::takeVectorsAndScalars(const KstVectorMap& vm, const KstScalarMap& sm) {
   bool rc = true;
   for (Node *i = _args.first(); i; i = _args.next()) {
-    rc = i->takeVectors(c) && rc;
+    rc = i->takeVectorsAndScalars(vm, sm) && rc;
   }
   return rc;
 }
@@ -797,8 +807,9 @@ double Data::value(Context *ctx) {
   if (_isEquation) {
     if (!_equation) {
       mutex().lock();
-      yy_scan_string(_tagName.latin1());
+      YY_BUFFER_STATE b = yy_scan_bytes(_tagName.latin1(), _tagName.length());
       int rc = yyparse();
+      yy_delete_buffer(b);
       if (rc == 0 && ParsedEquation) {
         _equation = static_cast<Equation::Node*>(ParsedEquation);
         ParsedEquation = 0L;
@@ -820,8 +831,9 @@ double Data::value(Context *ctx) {
   } else if (_vector) {
     if (!_equation && !_vectorIndex.isEmpty()) {
       mutex().lock();
-      yy_scan_string(_vectorIndex.latin1());
+      YY_BUFFER_STATE b = yy_scan_bytes(_vectorIndex.latin1(), _vectorIndex.length());
       int rc = yyparse();
+      yy_delete_buffer(b);
       if (rc == 0 && ParsedEquation) {
         _equation = static_cast<Equation::Node*>(ParsedEquation);
         ParsedEquation = 0L;
@@ -875,16 +887,30 @@ bool Data::collectObjects(KstVectorMap& v, KstScalarMap& s, KstStringMap& t) {
 }
 
 
-bool Data::takeVectors(const KstVectorMap& c) {
+bool Data::takeVectorsAndScalars(const KstVectorMap& vm, const KstScalarMap& sm) {
   if (_isEquation) {
     if (_equation) {
-      return _equation->takeVectors(c);
+      return _equation->takeVectorsAndScalars(vm, sm);
     }
     return false;
   }
-  if (!_scalar) {
-    if (c.contains(_tagName)) {
-      _vector = c[_tagName];
+  if (_vector) {
+    if (vm.contains(_tagName)) {
+      _vector = vm[_tagName];
+    } else {
+      return false;
+    }
+  } else if (_scalar) {
+    if (sm.contains(_tagName)) {
+      _scalar = sm[_tagName];
+    } else {
+      return false;
+    }
+  } else {
+    if (vm.contains(_tagName)) {
+      _vector = vm[_tagName];
+    } else if (sm.contains(_tagName)) {
+      _scalar = sm[_tagName];
     } else {
       return false;
     }
@@ -900,8 +926,10 @@ KstObject::UpdateType Data::update(int counter, Context *ctx) {
       return _equation->update(counter, ctx);
     }
   } else if (_vector) {
+    KstWriteLocker l(_vector);
     return _vector->update(counter);
   } else if (_scalar) {
+    KstWriteLocker l(_scalar);
     return _scalar->update(counter);
   }
   return KstObject::NO_CHANGE;
