@@ -256,6 +256,10 @@ KstObject::UpdateType KstCPlugin::update(int update_counter) {
     return setLastUpdateResult(NO_CHANGE);
   }
 
+  if (recursed()) {
+    return setLastUpdateResult(NO_CHANGE);
+  }
+
   bool force = dirty();
   setDirty(false);
 
@@ -528,10 +532,18 @@ bool KstCPlugin::isValid() const {
 
 
 QString KstCPlugin::propertyString() const {
+  QString str;
+
   if (!isValid()) {
-    return i18n("Invalid plugin.");
+    str = i18n("Invalid plugin.");
+  } else {
+    str = plugin()->data()._readableName;
+    if (str.isEmpty()) {
+      str = plugin()->data()._name;
+    }
   }
-  return plugin()->data()._name;
+
+  return str;
 }
 
 
@@ -652,12 +664,13 @@ QString KstCPlugin::lastError() const {
 
 KstDataObject::Kind KstCPlugin::kind() const {
 
-  if (_plugin->data()._isFit)
+  if (_plugin->data()._isFit) {
     return Fit;
-  else if (_plugin->data()._isFilter)
+  } else if (_plugin->data()._isFilter) {
     return Filter;
-  else
-    return Generic;
+  }
+
+  return KstPlugin;
 }
 
 
