@@ -15,9 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-/** A class for handling Spectrograms for kst
- */
-
 #ifndef KSTCSD_H
 #define KSTCSD_H
 
@@ -39,7 +36,7 @@ class KST_EXPORT KstCSD : public KstDataObject {
 
     virtual void save(QTextStream& ts, const QString& indent = QString::null);
     virtual QString propertyString() const;
-    
+
     QString vTag() const;
     void setVector(KstVectorPtr);
 
@@ -59,30 +56,33 @@ class KST_EXPORT KstCSD : public KstDataObject {
 
     double freq() const;
     void setFreq(double in_freq);
-    
+
     ApodizeFunction apodizeFxn() const;
     void setApodizeFxn(ApodizeFunction in_fxn);
-    
+
     double gaussianSigma() const;
     void setGaussianSigma(double in_sigma);
-    
+
     int windowSize() const;
     void setWindowSize(int in_size); 
-    
+
     int length() const;
     void setLength(int in_length);
-    
+
     const QString& vectorUnits() const;
     void setVectorUnits(const QString& units);
-    
+
     const QString& rateUnits() const;
     void setRateUnits(const QString& units);
-    
+
     PSDType output() const;
     void setOutput(PSDType in_outputType);
-    
+
+    bool interpolateHoles() const;
+    void setInterpolateHoles(bool interpolate);
+
     KstMatrixPtr outputMatrix() const;
-    
+
     virtual KstDataObjectPtr makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap);
 
   private:
@@ -90,12 +90,13 @@ class KST_EXPORT KstCSD : public KstDataObject {
                             bool in_removeMean, bool in_apodize, ApodizeFunction in_apodizeFxn, 
                             int in_windowSize, int in_length, double in_gaussianSigma, 
                             const QString& in_vectorUnits, const QString& in_rateUnits, 
-                            PSDType in_outputType, const QString& vecName);
+                            PSDType in_outputType, bool interpolateHoles, const QString& vecName);
 
     void updateMatrixLabels();
-    
+
     double _frequency;
     bool _average;
+    bool _interpolateHoles;
     bool _removeMean;
     bool _apodize;
     ApodizeFunction _apodizeFxn;
