@@ -40,6 +40,7 @@ KstDataObject::KstDataObject() : KstObject() {
   //kstdDebug() << "+++ CREATING DATA OBJECT: " << (void*)this << endl;
   _curveHints = new KstCurveHintList;
   _isInputLoaded = false;
+  _isRecursed = false;
 }
 
 KstDataObject::KstDataObject(const QDomElement& e) : KstObject() {
@@ -47,6 +48,7 @@ KstDataObject::KstDataObject(const QDomElement& e) : KstObject() {
   //kstdDebug() << "+++ CREATING DATA OBJECT: " << (void*)this << endl;
   _curveHints = new KstCurveHintList;
   _isInputLoaded = false;
+  _isRecursed = false;
 }
 
 
@@ -674,8 +676,8 @@ bool KstDataObject::uses(KstObjectPtr p) const {
     for (KstScalarMap::ConstIterator j = _inputScalars.begin(); j != _inputScalars.end(); ++j) {
       for (; scalarDictIter.current(); ++scalarDictIter) {
         if (scalarDictIter.current() == j.data()) {
-          return true;  
-        }  
+          return true;
+        }
       }
     }
   } else if (KstMatrixPtr matrix = kst_cast<KstMatrix>(p)) {
@@ -688,8 +690,8 @@ bool KstDataObject::uses(KstObjectPtr p) const {
     for (KstScalarMap::ConstIterator j = _inputScalars.begin(); j != _inputScalars.end(); ++j) {
       for (; scalarDictIter.current(); ++scalarDictIter) {
         if (scalarDictIter.current() == j.data()) {
-          return true;  
-        }  
+          return true;
+        }
       }
     }
   } else if (KstDataObjectPtr obj = kst_cast<KstDataObject>(p) ) {
@@ -706,11 +708,11 @@ bool KstDataObject::uses(KstObjectPtr p) const {
         for (; scalarDictIter.current(); ++scalarDictIter) {
           if (scalarDictIter.current() == k.data()) {
             return true;
-          }  
+          }
         }
       }
     }
-  
+
     for (KstMatrixMap::Iterator j = obj->outputMatrices().begin(); j != obj->outputMatrices().end(); ++j) {
       for (KstMatrixMap::ConstIterator k = _inputMatrices.begin(); k != _inputMatrices.end(); ++k) {
         if (j.data() == k.data()) {
@@ -723,19 +725,19 @@ bool KstDataObject::uses(KstObjectPtr p) const {
         for (; scalarDictIter.current(); ++scalarDictIter) {
           if (scalarDictIter.current() == k.data()) {
             return true;
-          }  
+          }
         }
       }
     }
-    
+
     for (KstScalarMap::Iterator j = obj->outputScalars().begin(); j != obj->outputScalars().end(); ++j) {
       for (KstScalarMap::ConstIterator k = _inputScalars.begin(); k != _inputScalars.end(); ++k) {
         if (j.data() == k.data()) {
           return true;
         }
-      } 
+      }
     }
-  
+
     for (KstStringMap::Iterator j = obj->outputStrings().begin(); j != obj->outputStrings().end(); ++j) {
       for (KstStringMap::ConstIterator k = _inputStrings.begin(); k != _inputStrings.end(); ++k) {
         if (j.data() == k.data()) {
@@ -744,9 +746,57 @@ bool KstDataObject::uses(KstObjectPtr p) const {
       }
     }
   }
+
   return false;
 }
 
 
+bool KstDataObject::recursion(KstDataObjectDataObjectMap& objectsInUse) {
+  bool recurses = false;
+
+  objectsInUse.insert(this, this);
+
+  for (KstDataObjectList::Iterator it = KST::dataObjectList.begin(); it != KST::dataObjectList.end(); ++it) {
+    if ((*it)->uses(this)) {
+      if (objectsInUse.find(*it) == objectsInUse.end()) {
+        if ((*it)->recursion(objectsInUse)) {
+          recurses = true;
+
+          break;
+        }
+      } else {
+        recurses = true;
+
+        break;
+      }
+    }
+  }
+
+  objectsInUse.remove(this);
+
+  return recurses;
+}
+
+
+bool KstDataObject::recursion() {
+  KstDataObjectDataObjectMap objectsInUse;
+  bool recurses = false;
+
+  recurses = recursion(objectsInUse);
+
+  return recurses;
+}
+
+
+void KstDataObject::setRecursed( bool isRecursed ) {
+  _isRecursed = isRecursed;
+}
+
+
+bool KstDataObject::recursed() const {
+  return _isRecursed;
+}
+
+
 #include "kstdataobject.moc"
-// vim: ts=2 sw=2 et
+
