@@ -158,6 +158,10 @@ KstObject::UpdateType KstHistogram::update(int update_counter) {
   bool force = dirty();
   setDirty(false);
 
+  if (recursed()) {
+    return setLastUpdateResult(KstObject::NO_CHANGE);
+  }
+
   if (KstObject::checkUpdateCounter(update_counter) && !force) {
     return lastUpdateResult();
   }
@@ -320,6 +324,7 @@ QString KstHistogram::vTag() const {
 
 void KstHistogram::setVector(KstVectorPtr new_v) {
   _inputVectors[RAWVECTOR] = new_v;
+  setRecursed(false);
 }
 
 
@@ -440,21 +445,6 @@ bool KstHistogram::realTimeAutoBin() const {
 }
 
 
-double KstHistogram::vMax() const {
-  return _inputVectors[RAWVECTOR]->max();
-}
-
-
-double KstHistogram::vMin() const {
-  return _inputVectors[RAWVECTOR]->min();
-}
-
-
-int KstHistogram::vNumSamples() const {
-  return _inputVectors[RAWVECTOR]->length();
-}
-
-
 KstDataObjectPtr KstHistogram::makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap) {
   QString name(tagName() + '\'');
   while (KstData::self()->dataTagNameNotUnique(name, false)) {
@@ -466,5 +456,3 @@ KstDataObjectPtr KstHistogram::makeDuplicate(KstDataObjectDataObjectMap& duplica
   return KstDataObjectPtr(histogram);
 }
 
-
-// vim: ts=2 sw=2 et
