@@ -57,6 +57,17 @@ struct AxisDisplay {
   KstAxisDisplay type;
 };
 
+struct MajorTickSpacing {
+  const char *label;
+  int majorTickDensity;
+};
+
+struct TickLabelDescription {
+  QString label;
+  double position;
+  bool minorTick;
+};
+
 const AxisInterpretation AxisInterpretations[] = {
   { I18N_NOOP("Julian Year"), AXIS_INTERP_YEAR },
   { I18N_NOOP("Standard C time"), AXIS_INTERP_CTIME },
@@ -64,7 +75,7 @@ const AxisInterpretation AxisInterpretations[] = {
   { I18N_NOOP2("Modified Julian Date", "MJD"), AXIS_INTERP_MJD },
   { I18N_NOOP2("Reduced Julian Date", "RJD"), AXIS_INTERP_RJD },
   { I18N_NOOP2("Temps Atomique International", "TAI"), AXIS_INTERP_AIT }
-};          
+};
 
 const AxisDisplay AxisDisplays[] = {
   { I18N_NOOP("Julian Year"), AXIS_DISPLAY_YEAR },
@@ -79,30 +90,37 @@ const AxisDisplay AxisDisplays[] = {
   { I18N_NOOP("<KDE Long Date and Time>"), AXIS_DISPLAY_KDE_LONGDATE }
 };
 
+const MajorTickSpacing MajorTickSpacings[] = {
+  { I18N_NOOP("Coarse"), 2 },
+  { I18N_NOOP("Default"), 5 },
+  { I18N_NOOP("Fine"), 10 },
+  { I18N_NOOP("Very fine"), 15 }
+};
+
 class TickParameters {
   public:
     // FIXME: use reasonable defaults
-    TickParameters() : org(0.0), tick(0.0), delta(false), maxWidth(0.0),
-                       maxHeight(0.0), iHi(0), iLo(0), oppMaxWidth(0.0),
-                       oppMaxHeight(0.0)
+    TickParameters() : org(0.0), tick(0.0), delta(false), labelMinor(false), maxWidth(0.0),
+                       maxHeight(0.0), iHi(0), iLo(0), oppMaxWidth(0.0), oppMaxHeight(0.0)
     {}
 
     double org;
     double tick;
     bool delta;
+    bool labelMinor;
     double maxWidth;
     double maxHeight;
-    QStringList labels;
+    QValueList<TickLabelDescription> labels;
+    QValueList<TickLabelDescription> labelsOpposite;
     int iHi;
     int iLo;
-    QStringList oppLabels; // labels for the opposite axis
     double oppMaxWidth;
     double oppMaxHeight;
 };
 
 const unsigned int numAxisInterpretations = sizeof( AxisInterpretations ) / sizeof( AxisInterpretation );
 const unsigned int numAxisDisplays = sizeof( AxisDisplays ) / sizeof( AxisDisplay );
-
+const unsigned int numMajorTickSpacings = sizeof( MajorTickSpacings ) / sizeof( MajorTickSpacing );
 
 #endif
 // vim: ts=2 sw=2 et
