@@ -152,7 +152,7 @@ KstVCurve::KstVCurve(QDomElement &e)
       } else if (e.tagName() == "hasBars") {
         HasBars = e.text() != "0";
       } else if (e.tagName() == "pointType") {
-        pointType = e.text().toInt();
+        PointStyle = e.text().toInt();
       } else if (e.tagName() == "lineWidth") {
         LineWidth = e.text().toInt();
       } else if (e.tagName() == "lineStyle") {
@@ -514,7 +514,7 @@ void KstVCurve::save(QTextStream &ts, const QString& indent) {
   if (HasPoints) {
     ts << l2 << "<hasPoints/>" << endl;
   }
-  ts << l2 << "<pointType>" << pointType << "</pointType>" << endl;
+  ts << l2 << "<pointType>" << PointStyle << "</pointType>" << endl;
   ts << l2 << "<pointDensity>" << PointDensity << "</pointDensity>" << endl;
   if (HasBars) {
     ts << l2 << "<hasBars/>" << endl;
@@ -796,9 +796,11 @@ void KstVCurve::setLineWidth(int in_LineWidth) {
 
 
 void KstVCurve::setLineStyle(int in_LineStyle) {
-  LineStyle = in_LineStyle;
-  setDirty();
-  emit modifiedLegendEntry();
+  if (in_LineStyle >= 0 && (unsigned int)in_LineStyle < KSTLINESTYLE_MAXTYPE) {
+    LineStyle = in_LineStyle;
+    setDirty();
+    emit modifiedLegendEntry();
+  }
 }
 
 
@@ -810,9 +812,20 @@ void KstVCurve::setBarStyle(int in_BarStyle) {
 
 
 void KstVCurve::setPointDensity(int in_PointDensity) {
-  PointDensity = in_PointDensity;
-  setDirty();
-  emit modifiedLegendEntry();
+  if (in_PointDensity >= 0 && (unsigned int)in_PointDensity < KSTPOINTDENSITY_MAXTYPE) {
+    PointDensity = in_PointDensity;
+    setDirty();
+  }
+}
+
+
+void KstVCurve::setPointStyle(int in_PointStyle) {
+  if (in_PointStyle >= 0 && (unsigned int)in_PointStyle < KSTPOINT_MAXTYPE)
+  {
+    PointStyle = in_PointStyle;
+    setDirty();
+    emit modifiedLegendEntry();
+  }
 }
 
 
@@ -1358,12 +1371,14 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 
     // draw the points, if any...
     if (hasPoints()) {
-      if (hasLines() && pointDensity() != 0) {
+      if (hasLines() && pointDensity() > 0 && 
+          (unsigned int)pointDensity() < KSTPOINTDENSITY_MAXTYPE) {
         const double w = Hx - Lx;
         const double h = Hy - Ly;
-        QRegion rgn((int)Lx, (int)Ly, (int)w, (int)h);
         const int size = int(kMax(w, h)) / int(pow(3.0, KSTPOINTDENSITY_MAXTYPE - pointDensity()));
+        QRegion rgn((int)Lx, (int)Ly, (int)w, (int)h);
         QPoint pt;
+
         for (i_pt = i0; i_pt <= iN; ++i_pt) {
           rX = xv->interpolate(i_pt, NS);
           rY = yv->interpolate(i_pt, NS);
@@ -1377,7 +1392,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           pt.setX(d2i(m_X * rX + b_X));
           pt.setY(d2i(m_Y * rY + b_Y));
           if (rgn.contains(pt)) {
-            KstCurvePointSymbol::draw(pointType, p, pt.x(), pt.y(), width);
+            KstCurvePointSymbol::draw(PointStyle, p, pt.x(), pt.y(), width);
             rgn -= QRegion(pt.x()-(size/2), pt.y()-(size/2), size, size, QRegion::Ellipse);
           }
         }
@@ -1395,7 +1410,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           X1 = m_X * rX + b_X;
           Y1 = m_Y * rY + b_Y;
           if (X1 >= Lx && X1 <= Hx && Y1 >= Ly && Y1 <= Hy) {
-            KstCurvePointSymbol::draw(pointType, p, d2i(X1), d2i(Y1), width);
+            KstCurvePointSymbol::draw(PointStyle, p, d2i(X1), d2i(Y1), width);
           }
         }
       }
@@ -1717,13 +1732,13 @@ double KstVCurve::distanceToPoint(double xpos, double dx, double ypos) const {
 
 void KstVCurve::paintLegendSymbol(KstPainter *p, const QRect& bound) {
   int width;
-  
+
   if (lineWidth() == 0) {
     width = p->lineWidthAdjustmentFactor();
-  } else {  
+  } else {
     width = lineWidth() * p->lineWidthAdjustmentFactor();
   }
-  
+
   p->save();
   if (hasLines()) {
     // draw a line from left to right centered vertically
@@ -1734,7 +1749,7 @@ void KstVCurve::paintLegendSymbol(KstPainter *p, const QRect& bound) {
   if (hasPoints()) {
     // draw a point in the middle
     p->setPen(QPen(color(), width));
-    KstCurvePointSymbol::draw(pointType, p, bound.left() + bound.width()/2, bound.top() + bound.height()/2, width, 600);
+    KstCurvePointSymbol::draw(PointStyle, p, bound.left() + bound.width()/2, bound.top() + bound.height()/2, width, 600);
   }
   p->restore();
 }
@@ -1744,10 +1759,9 @@ KstVCurve::InterpType KstVCurve::interp() const {
   return (_interp);
 }
 
+
 void KstVCurve::setInterp(KstVCurve::InterpType itype) {
   _interp = itype;
   setDirty();
 }
 
-
-// vim: ts=2 sw=2 et
