@@ -316,7 +316,7 @@ inline bool parseOutChar(const QString& txt, uint from, int *skip, Chunk **tail,
       } else {
         *skip = 1;
         setNormalChar(QChar(0x20), tail);  
-        return true;      
+        return true;
       }
       break;
 
@@ -464,6 +464,15 @@ inline bool parseOutChar(const QString& txt, uint from, int *skip, Chunk **tail,
         *skip = 7;
         setNormalChar(QChar(0x3A5+x), tail);
         return true;
+      } else if (txt.mid(from + 1).startsWith("nichar{")) {
+        int charStart = from + 8;
+        int charEnd = txt.find('}', charStart);
+        if (charEnd == -1) {
+          return false;
+        }
+        setNormalChar(QChar( (txt.mid(charStart,charEnd - charStart)).toInt(0,0)), tail);
+        *skip = charEnd - from + 1;
+        return true;
       }
       break;
 
